"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardDomainName = void 0;
const tmroute53 = require("../../aws-route53");
const targets = require("aws-cdk-lib/aws-route53-targets");
const aws_apigatewayv2_1 = require("aws-cdk-lib/aws-apigatewayv2");
const aws_route53_1 = require("aws-cdk-lib/aws-route53");
const aws_route53_2 = require("../../aws-route53");
const aws_cdk_1 = require("../../aws-cdk");
const truemark_1 = require("../../truemark");
/**
 * Standard construct used to create an API Gateway V2 Domain Name.
 */
class StandardDomainName extends aws_cdk_1.ExtendedConstruct {
    constructor(scope, id, props) {
        var _a;
        super(scope, id, {
            standardTags: aws_cdk_1.StandardTags.merge(props.standardTags, truemark_1.LibStandardTags),
        });
        this.domainName = new tmroute53.DomainName(props);
        this.certificate =
            (_a = props.certificate) !== null && _a !== void 0 ? _a : this.domainName.createCertificate(scope);
        this.gatewayDomainName = new aws_apigatewayv2_1.DomainName(this, 'Default', {
            domainName: this.domainName.toString(),
            certificate: this.certificate,
            securityPolicy: props.securityPolicy,
        });
    }
    toRecordTarget(evaluateTargetHealth) {
        const domainProperties = new targets.ApiGatewayv2DomainProperties(this.gatewayDomainName.regionalDomainName, this.gatewayDomainName.regionalHostedZoneId);
        return evaluateTargetHealth
            ? aws_route53_2.ExtendedRecordTarget.fromAlias(domainProperties, evaluateTargetHealth)
            : aws_route53_1.RecordTarget.fromAlias(domainProperties);
    }
    /**
     * Creates a route53 ARecord pointing to this domain name.
     *
     * @param evaluateTargetHealth Determines if route53 evaluates the target's health. Defaults to true.
     * @param options additional options for creating the record
     */
    createARecord(evaluateTargetHealth, options) {
        return this.domainName.createARecord(this, this.toRecordTarget(evaluateTargetHealth !== null && evaluateTargetHealth !== void 0 ? evaluateTargetHealth : true), options);
    }
    /**
     * Creates a route53 weighted record pointing to this domain name.
     *
     * @param weight the initial weight; defaults to 0
     * @param evaluateTargetHealth Determines if route53 evaluates the target's health. Defaults to true.
     * @param options additional options for creating the record
     */
    createWeightedARecord(weight, evaluateTargetHealth, options) {
        return this.domainName.createWeightedARecord(this, this.toRecordTarget(evaluateTargetHealth !== null && evaluateTargetHealth !== void 0 ? evaluateTargetHealth : true), weight, options);
    }
    /**
     * Creates a route53 latency record pointing to this domain name.
     *
     * @param evaluateTargetHealth Determines if route53 evaluates the target's health. Defaults to true.
     * @param options additional options for creating the record
     */
    createLatencyARecord(evaluateTargetHealth, options) {
        return this.domainName.createLatencyARecord(this, this.toRecordTarget(evaluateTargetHealth !== null && evaluateTargetHealth !== void 0 ? evaluateTargetHealth : true), options);
    }
    /**
     * Returns the FQDN of this domain name.
     */
    toString() {
        return this.domainName.toString();
    }
}
exports.StandardDomainName = StandardDomainName;
//# sourceMappingURL=standard-domain-name.js.map