"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardWebSocketApi = void 0;
const standard_domain_name_1 = require("./standard-domain-name");
const aws_apigatewayv2_1 = require("aws-cdk-lib/aws-apigatewayv2");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_cdk_1 = require("../../aws-cdk");
/**
 * Abstraction that creates an WebSocketApi with support infrastructure.
 */
class StandardWebSocketApi extends aws_cdk_1.ExtendedConstruct {
    constructor(scope, id, props) {
        var _a, _b, _c;
        super(scope, id);
        const domainName = new standard_domain_name_1.StandardDomainName(this, 'DomainName', {
            prefix: props.domainPrefix,
            zone: props.domainZone,
            securityPolicy: aws_apigatewayv2_1.SecurityPolicy.TLS_1_2, // TODO Should be an option
        });
        // TODO Need to add RecordOptions
        if ((_a = props.createRecord) !== null && _a !== void 0 ? _a : true) {
            if (props.recordWeight) {
                domainName.createWeightedARecord(props.recordWeight, (_b = props.evaluateTargetHealth) !== null && _b !== void 0 ? _b : true);
            }
            else if (props.recordLatency) {
                domainName.createLatencyARecord(true);
            }
            else {
                domainName.createARecord();
            }
        }
        else {
            this.record = undefined;
        }
        const stage = aws_cdk_lib_1.Stage.of(this);
        const stack = aws_cdk_lib_1.Stack.of(this);
        const webSocketApi = new aws_apigatewayv2_1.WebSocketApi(this, 'Default', {
            apiName: (_c = props.apiName) !== null && _c !== void 0 ? _c : `${stage === null || stage === void 0 ? void 0 : stage.stageName}${stack === null || stack === void 0 ? void 0 : stack.stackName}Gateway`,
        });
        const webSocketStage = new aws_apigatewayv2_1.WebSocketStage(this, 'DefaultStage', {
            webSocketApi,
            stageName: 'default',
            autoDeploy: true,
            domainMapping: {
                domainName: domainName.gatewayDomainName,
            },
        });
        this.webSocketApi = webSocketApi;
        this.webSocketStage = webSocketStage;
    }
}
exports.StandardWebSocketApi = StandardWebSocketApi;
//# sourceMappingURL=standard-web-socket-api.js.map