import { App, AppProps } from 'aws-cdk-lib';
import { StandardTagsProps } from './standard-tags';
/**
 * Properties for ExtendedApp.
 */
export interface ExtendedAppProps extends AppProps {
    /**
     * Standard tags to apply to all stacks.
     */
    readonly standardTags?: StandardTagsProps;
    /**
     * Skips account lookup and uses this account.
     */
    readonly account?: string;
    /**
     * Skips region lookup and uses this region.
     */
    readonly region?: string;
}
/**
 * Adds functionality to the base App class to support standard tags
 * and access to the account and region being used to execute the
 * CDK process.
 */
export declare class ExtendedApp extends App {
    readonly account: string;
    readonly region: string;
    constructor(props?: ExtendedAppProps);
}
