"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtendedApp = void 0;
const aws_cdk_lib_1 = require("aws-cdk-lib");
/**
 * Adds functionality to the base App class to support standard tags
 * and access to the account and region being used to execute the
 * CDK process.
 */
class ExtendedApp extends aws_cdk_lib_1.App {
    constructor(props) {
        super({
            ...props,
            context: {
                ...props === null || props === void 0 ? void 0 : props.context,
                // Add standardTags to the context to be used by ExtendedStack
                standardTags: props === null || props === void 0 ? void 0 : props.standardTags,
            },
        });
        // Use the provided account or do a lookup
        const account = (props === null || props === void 0 ? void 0 : props.account) ||
            process.env.CDK_DEFAULT_ACCOUNT ||
            process.env.AWS_ACCOUNT_ID;
        if (account === undefined) {
            throw new Error('Unable to identify default account');
        }
        this.account = account;
        // Use the provided region or do a lookup
        const region = (props === null || props === void 0 ? void 0 : props.region) ||
            process.env.CDK_DEFAULT_REGION ||
            process.env.AWS_DEFAULT_REGION;
        if (region === undefined) {
            throw new Error('Unable to identify default region');
        }
        this.region = region;
        // Add automation component tags to AutomationComponent children
        // Aspects.of(this).add(new AutomationComponentAspect(props?.standardTags?.suppressTagging));
    }
}
exports.ExtendedApp = ExtendedApp;
//# sourceMappingURL=extended-app.js.map