"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtendedStack = void 0;
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_ssm_1 = require("../../aws-ssm");
const cdk_monitoring_constructs_1 = require("cdk-monitoring-constructs");
const standard_tags_1 = require("./standard-tags");
/**
 * Extended version of Stack providing functionality for parameter exports and monitoring.
 */
class ExtendedStack extends aws_cdk_lib_1.Stack {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        super(scope, id, props);
        const stageName = (_a = aws_cdk_lib_1.Stage.of(this)) === null || _a === void 0 ? void 0 : _a.stageName;
        this.parameterExportOptions = {
            prefix: (_b = props === null || props === void 0 ? void 0 : props.parameterExportsPrefix) !== null && _b !== void 0 ? _b : (stageName === undefined ? '' : `/${stageName}`) + `/${id}/Exports/`,
            region: this.region,
        };
        this.parameterExports = new aws_ssm_1.ParameterStore(this, 'ParameterExports', this.parameterExportOptions);
        if ((_c = props === null || props === void 0 ? void 0 : props.createMonitoringFacade) !== null && _c !== void 0 ? _c : true) {
            const dashboardFactory = new cdk_monitoring_constructs_1.DefaultDashboardFactory(this, 'DashboardFactory', {
                dashboardNamePrefix: (_d = props === null || props === void 0 ? void 0 : props.dashboardNamePrefix) !== null && _d !== void 0 ? _d : this.stackName,
                createAlarmDashboard: (_e = props === null || props === void 0 ? void 0 : props.createAlarmDashboard) !== null && _e !== void 0 ? _e : false,
                createDashboard: (_f = props === null || props === void 0 ? void 0 : props.createDashboard) !== null && _f !== void 0 ? _f : false,
                createSummaryDashboard: (_g = props === null || props === void 0 ? void 0 : props.createSummaryDashboard) !== null && _g !== void 0 ? _g : false,
                renderingPreference: (_h = props === null || props === void 0 ? void 0 : props.dashboardRenderingPreference) !== null && _h !== void 0 ? _h : cdk_monitoring_constructs_1.DashboardRenderingPreference.INTERACTIVE_ONLY,
            });
            this.monitoringFacade = new cdk_monitoring_constructs_1.MonitoringFacade(this, 'Monitoring', {
                metricFactoryDefaults: {
                    namespace: props === null || props === void 0 ? void 0 : props.metricNamespace,
                    period: props === null || props === void 0 ? void 0 : props.metricPeriod,
                },
                alarmFactoryDefaults: {
                    actionsEnabled: (_j = props === null || props === void 0 ? void 0 : props.alarmActionsEnabled) !== null && _j !== void 0 ? _j : true,
                    alarmNamePrefix: this.stackName,
                },
                dashboardFactory: dashboardFactory,
            });
        }
        // Setup standard tags
        this.standardTags = new standard_tags_1.StandardTags(this, props === null || props === void 0 ? void 0 : props.standardTags);
    }
    /**
     * Helper method to exports a parameter as an SSM Parameter.
     *
     * @param name the parameter name
     * @param value the parameter value
     */
    exportParameter(name, value) {
        return this.parameterExports.write(name, value);
    }
    /**
     * Helper method to output a parameter as a CfnOutput.
     *
     * @param name the parameter name
     * @param value the parameter value
     */
    outputParameter(name, value) {
        return new aws_cdk_lib_1.CfnOutput(this, name, {
            value,
        });
    }
}
exports.ExtendedStack = ExtendedStack;
//# sourceMappingURL=extended-stack.js.map