"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SingleEnvApp = void 0;
const helpers_1 = require("../../helpers");
const extended_app_1 = require("./extended-app");
const standard_tags_1 = require("./standard-tags");
/**
 * Extension of ExtendedApp that supports a standard way to declare environment names.
 */
class SingleEnvApp extends extended_app_1.ExtendedApp {
    constructor(props) {
        var _a, _b;
        super(props);
        const environmentPropertyName = (_a = props === null || props === void 0 ? void 0 : props.environmentPropertyName) !== null && _a !== void 0 ? _a : 'env';
        this.environmentName = this.node.tryGetContext(environmentPropertyName);
        if (!this.environmentName) {
            throw new Error(`Environment is missing. Please add "-c ${environmentPropertyName}=<name>" to your CDK command`);
        }
        if (!helpers_1.StringHelper.isLowerAlphanumeric(this.environmentName)) {
            throw new Error('Environment name must be lower case alpha numeric');
        }
        // Add environment to cost center tags
        if ((_b = props === null || props === void 0 ? void 0 : props.standardTags) === null || _b === void 0 ? void 0 : _b.costCenterTags) {
            new standard_tags_1.StandardTags(this).addCostCenterTags({
                ...props.standardTags.costCenterTags,
                environment: this.environmentName,
            });
        }
    }
    /**
     * Returns the name of the environment.
     */
    getEnvironmentName() {
        return this.environmentName;
    }
    /**
     * Returns the name of the environment in title case.
     */
    getEnvironmentNameTitleCase() {
        return helpers_1.StringHelper.toPascalCase(this.environmentName);
    }
}
exports.SingleEnvApp = SingleEnvApp;
//# sourceMappingURL=single-env-app.js.map