import { Construct } from 'constructs';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { ExtendedConstruct, ExtendedConstructProps } from '../../aws-cdk';
/**
 * Properties for AlertsTopic
 */
export interface AlertsTopicProps extends ExtendedConstructProps {
    /**
     * Overrides default topic display name.
     *
     * @default "CenterGaugeAlerts"
     */
    readonly displayName?: string;
    /**
     * Overrides the use of the default aws/sns KMS key for encryption
     *
     * @default uses AWS managed SNS KMS key
     */
    readonly masterKey?: IKey;
    /**
     * Overrides the default alerts URL.
     *
     * @default https://alerts.centergauge.com/
     */
    readonly url?: string;
    /**
     * Setting this to true will suppress the creation of default tags on resources
     * created by this construct. Default is false.
     *
     * @default - false
     */
    readonly suppressTagging?: boolean;
}
/**
 * Sets up an SNS Topic that will send notifications to CenterGauge.
 */
export declare class AlertsTopic extends ExtendedConstruct {
    constructor(scope: Construct, id: string, props: AlertsTopicProps);
}
