"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AlertsTopic = void 0;
const aws_sns_1 = require("aws-cdk-lib/aws-sns");
const aws_kms_1 = require("aws-cdk-lib/aws-kms");
const aws_sqs_1 = require("../../aws-sqs");
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
const aws_cdk_1 = require("../../aws-cdk");
const truemark_1 = require("../../truemark");
/**
 * Sets up an SNS Topic that will send notifications to CenterGauge.
 */
class AlertsTopic extends aws_cdk_1.ExtendedConstruct {
    constructor(scope, id, props) {
        var _a, _b, _c;
        super(scope, id, {
            standardTags: aws_cdk_1.StandardTags.merge(props.standardTags, truemark_1.LibStandardTags),
        });
        const masterKey = (_a = props.masterKey) !== null && _a !== void 0 ? _a : aws_kms_1.Alias.fromAliasName(this, 'AwsSnsKey', 'aws/sns');
        const dlq = new aws_sqs_1.StandardQueue(this, 'Dlq', {
            maxReceiveCount: -1,
            criticalAlarmOptions: {
                maxSize: 1,
            },
        });
        const topic = new aws_sns_1.Topic(this, 'Default', {
            displayName: (_b = props.displayName) !== null && _b !== void 0 ? _b : 'CenterGaugeAlerts',
            fifo: false,
            masterKey,
        });
        dlq.addToResourcePolicy(new aws_iam_1.PolicyStatement({
            effect: aws_iam_1.Effect.ALLOW,
            sid: 'First',
            principals: [new aws_iam_1.AnyPrincipal()],
            actions: ['sqs:SendMessage'],
            conditions: {
                ArnEquals: {
                    'aws:SourceArn': topic.topicArn,
                },
            },
        }));
        new aws_sns_1.CfnSubscription(this, 'Subscription', {
            topicArn: topic.topicArn,
            protocol: 'https',
            endpoint: (_c = props.url) !== null && _c !== void 0 ? _c : 'https://alerts.centergauge.com/',
            rawMessageDelivery: false,
            deliveryPolicy: {
                healthyRetryPolicy: {
                    numRetries: 10,
                    numNoDelayRetries: 0,
                    minDelayTarget: 30,
                    maxDelayTarget: 120,
                    numMinDelayRetries: 3,
                    numMaxDelayRetries: 0,
                    backoffFunction: 'linear',
                },
            },
            redrivePolicy: JSON.stringify({
                deadLetterTargetArn: dlq.queueArn,
            }),
        });
    }
}
exports.AlertsTopic = AlertsTopic;
//# sourceMappingURL=alerts-topic.js.map