import { AllowedMethods, BehaviorOptions, CachedMethods, Distribution, DistributionProps, EdgeLambda, FunctionAssociation, ICachePolicy, IFunction, IKeyGroup, IOrigin, IOriginRequestPolicy, IResponseHeadersPolicy, ViewerProtocolPolicy } from 'aws-cdk-lib/aws-cloudfront';
import { RedirectFunctionProps } from './redirect-function';
import { DistributionBuilder } from './distribution-builder';
import { IBucket } from 'aws-cdk-lib/aws-s3';
import { CloudFrontBucket } from '../../aws-s3';
import { ExtendedConstruct } from '../../aws-cdk';
import { DomainName } from '../../aws-route53';
export declare const ALL_FALLBACK_STATUS_CODES: number[];
export declare const DEFAULT_FALLBACK_STATUS_CODES: number[];
export declare class BehaviorBuilder extends ExtendedConstruct {
    readonly path: string | undefined;
    protected options: BehaviorOptions;
    protected scope: DistributionBuilder;
    constructor(scope: DistributionBuilder, origin: IOrigin, path: string | undefined);
    fallbackOrigin(fallbackOrigin?: IOrigin, fallbackStatusCodes?: number[]): BehaviorBuilder;
    allowedMethods(allowedMethods?: AllowedMethods): BehaviorBuilder;
    cachedMethods(cachedMethods?: CachedMethods): BehaviorBuilder;
    cachePolicy(cachePolicy: ICachePolicy): BehaviorBuilder;
    compress(compress?: boolean): BehaviorBuilder;
    originRequestPolicy(originRequestPolicy?: IOriginRequestPolicy): BehaviorBuilder;
    responseHeadersPolicy(responseHeadersPolicy?: IResponseHeadersPolicy): BehaviorBuilder;
    smoothStreaming(smoothStreaming?: boolean): BehaviorBuilder;
    viewerProtocolPolicy(viewerProtocolPolicy?: ViewerProtocolPolicy): BehaviorBuilder;
    functionAssociations(functionAssociations?: FunctionAssociation[]): BehaviorBuilder;
    viewerRequestFunction(viewerRequestFunction: IFunction): BehaviorBuilder;
    redirectFunction(props: RedirectFunctionProps): BehaviorBuilder;
    viewerResponseFunction(viewerResponseFunction: IFunction): BehaviorBuilder;
    edgeLambdas(edgeLambdas?: EdgeLambda[]): BehaviorBuilder;
    trustedKeyGroups(trustedKeyGroups?: IKeyGroup[]): BehaviorBuilder;
    s3Defaults(): BehaviorBuilder;
    apiDefaults(additionalHeaders?: string[]): BehaviorBuilder;
    buildBehavior(): BehaviorOptions;
    build(): DistributionProps;
    behavior(origin: IOrigin, path: string): BehaviorBuilder;
    behaviorFromBucket(bucket: IBucket, path: string): BehaviorBuilder;
    behaviorFromCloudFromBucket(bucket: CloudFrontBucket, path: string): BehaviorBuilder;
    behaviorFromDomainName(domainName: string | DomainName, path: string): BehaviorBuilder;
    toDistribution(): Distribution;
}
