import { Distribution, DistributionProps, ErrorResponse, GeoRestriction, HttpVersion, IOrigin, PriceClass, SecurityPolicyProtocol, SSLMethod } from 'aws-cdk-lib/aws-cloudfront';
import { ICertificate } from 'aws-cdk-lib/aws-certificatemanager';
import { IBucket } from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
import { BehaviorBuilder } from './behavior-builder';
import { DomainName } from '../../aws-route53';
import { CloudFrontBucket } from '../../aws-s3';
import { ExtendedConstruct } from '../../aws-cdk';
export declare class DistributionBuilder extends ExtendedConstruct {
    protected props: any;
    protected behaviors: Record<string, BehaviorBuilder>;
    constructor(scope: Construct, id: string);
    getBehavior(path: string): BehaviorBuilder | undefined;
    behavior(origin: IOrigin, path?: string): BehaviorBuilder;
    behaviorFromBucket(bucket: IBucket, path?: string): BehaviorBuilder;
    behaviorFromCloudFromBucket(bucket: CloudFrontBucket, path?: string): BehaviorBuilder;
    behaviorFromDomainName(domainName: string | DomainName, path?: string): BehaviorBuilder;
    addBehavior(builder: BehaviorBuilder, path: string | undefined): DistributionBuilder;
    certificate(certificate?: ICertificate): DistributionBuilder;
    comment(comment?: string): DistributionBuilder;
    defaultRootObject(defaultRootObject?: string): DistributionBuilder;
    domainNames(...domainNames: (string | DomainName)[]): DistributionBuilder;
    domainName(domainName: string | DomainName): DistributionBuilder;
    enabled(enabled?: boolean): DistributionBuilder;
    enableIpv6(enableIpv6?: boolean): DistributionBuilder;
    enableLogging(enableLogging?: boolean): DistributionBuilder;
    geoRestriction(geoRestriction?: GeoRestriction): DistributionBuilder;
    httpVersion(httpVersion?: HttpVersion): DistributionBuilder;
    logBucket(logBucket?: IBucket): DistributionBuilder;
    logIncludesCookies(logIncludesCookies?: boolean): DistributionBuilder;
    logFilePrefix(logFilePrefix?: string): DistributionBuilder;
    priceClass(priceClass?: PriceClass): DistributionBuilder;
    webAclId(webAclId?: string): DistributionBuilder;
    errorResponses(errorResponses?: ErrorResponse[]): DistributionBuilder;
    errorResponse(errorResponse: ErrorResponse): DistributionBuilder;
    minimumProtocolVersion(minimumProtocolVersion?: SecurityPolicyProtocol): DistributionBuilder;
    sslSupportMethod(sslSupportMethod?: SSLMethod): DistributionBuilder;
    build(): DistributionProps;
    toDistribution(): Distribution;
}
