import { AwsCustomResource } from 'aws-cdk-lib/custom-resources';
import { Construct } from 'constructs';
import { Duration } from 'aws-cdk-lib';
/**
 * Properties for Invalidation.
 */
export interface InvalidationProps {
    /**
     * Distribution to submit invalidation for.
     */
    readonly distributionId: string;
    /**
     * The paths to invalidate.
     */
    readonly paths: string[];
    /**
     * The caller reference. Default is current timestamp.
     */
    readonly callerReference?: string;
    /**
     * The timeout for the Lambda function. Default is 2 minutes.
     *
     * @default Duration.minutes(2)
     */
    readonly timeout?: Duration;
    /**
     * Log retention days. The default is 5.
     */
    readonly logRetention?: number;
}
/**
 * Creates a CloudFront invalidation.
 */
export declare class Invalidation extends Construct {
    readonly resource: AwsCustomResource;
    constructor(scope: Construct, id: string, props: InvalidationProps);
}
