"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Invalidation = void 0;
const custom_resources_1 = require("aws-cdk-lib/custom-resources");
const constructs_1 = require("constructs");
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
/**
 * Creates a CloudFront invalidation.
 */
class Invalidation extends constructs_1.Construct {
    constructor(scope, id, props) {
        var _a, _b, _c;
        super(scope, id);
        const now = Date.now().toString();
        // https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/AWS/CloudFront.html
        const call = {
            service: 'CloudFront',
            action: 'createInvalidation',
            parameters: {
                DistributionId: props.distributionId,
                InvalidationBatch: {
                    CallerReference: (_a = props.callerReference) !== null && _a !== void 0 ? _a : now,
                    Paths: {
                        Quantity: props.paths.length,
                        Items: props.paths,
                    },
                },
            },
            physicalResourceId: custom_resources_1.PhysicalResourceId.of(now),
        };
        this.resource = new custom_resources_1.AwsCustomResource(this, 'Default', {
            onUpdate: call,
            logRetention: (_b = props.logRetention) !== null && _b !== void 0 ? _b : aws_logs_1.RetentionDays.FIVE_DAYS,
            installLatestAwsSdk: false,
            policy: {
                statements: [
                    new aws_iam_1.PolicyStatement({
                        resources: [
                            `arn:aws:cloudfront::${aws_cdk_lib_1.Stack.of(this).account}:distribution/${props.distributionId}`,
                        ],
                        actions: ['cloudfront:CreateInvalidation'],
                        effect: aws_iam_1.Effect.ALLOW,
                    }),
                ],
            },
            timeout: (_c = props.timeout) !== null && _c !== void 0 ? _c : aws_cdk_lib_1.Duration.minutes(2),
        });
    }
}
exports.Invalidation = Invalidation;
//# sourceMappingURL=invalidation.js.map