"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RedirectFunction = void 0;
const aws_cloudfront_1 = require("aws-cdk-lib/aws-cloudfront");
class RedirectFunction extends aws_cloudfront_1.Function {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f;
        super(scope, id, {
            code: aws_cloudfront_1.FunctionCode.fromInline(`
function handler(event) {
  var host = event.request.headers.host.value;
  var uri = event.request.uri;
  if ("APEX_DOMAIN" !== "" && host !== "APEX_DOMAIN") {
    return {
      statusCode: 301,
      statusDescription: "Permanently moved",
      headers: {
        "location": { "value": "https://APEX_DOMAIN" + uri }
      }
    }
  }
  if ("INDEX_FILE" !== "" && "NO_FILE_EXTENSION_BEHAVIOR" !== "None" && uri.split("/").pop().split(".").length <= 1) {
    if ("NO_FILE_EXTENSION_BEHAVIOR" === "ForwardToIndex") {
      event.request.uri = uri + "/INDEX_FILE";
    } else {
      return {
        statusCode: 301,
        statusDescription: "Permanently moved",
        headers: {
          "location": { "value": uri + "/" }
        }
      }
    }
  }
  if ("INDEX_FILE" !== "" && "TRAILING_SLASH_BEHAVIOR" !== "None" && uri.endsWith("/")) {
    if ("TRAILING_SLASH_BEHAVIOR" === "ForwardToIndex" || uri === "/") {
      event.request.uri = uri + "INDEX_FILE";
    } else {
      return {
        statusCode: 301,
        statusDescription: "Permanently moved",
        headers: {
          "location": { "value": uri.replace(/.$/, "") }
        }
      }
    }
  }
  if (event.request.uri === "/robots.txt" && "ROBOTS_BEHAVIOR" !== "None") {
    if ("ROBOTS_BEHAVIOR" === "Allow") {
      return {
        statusCode: 200,
        statusDescription: "OK",
        headers: {
         "content-type": { "value": "text/plain" }
        },
        body: "User-agent: *\\nAllow: /"
      }
    } else { // Disallow
      return {
        statusCode: 200,
        statusDescription: "OK",
        headers: {
         "content-type": { "value": "text/plain" }
        },
        body: "User-agent: *\\nDisallow: /"
      }
    }
  }
  return event.request;
}`
                .replace(/APEX_DOMAIN/g, (_b = (_a = props.apexDomain) === null || _a === void 0 ? void 0 : _a.toString()) !== null && _b !== void 0 ? _b : '')
                .replace(/INDEX_FILE/g, (_c = props.indexFile) !== null && _c !== void 0 ? _c : 'index.html')
                .replace(/NO_FILE_EXTENSION_BEHAVIOR/g, (_d = props.noFileExtensionBehavior) !== null && _d !== void 0 ? _d : 'None')
                .replace(/TRAILING_SLASH_BEHAVIOR/g, (_e = props.trailingSlashBehavior) !== null && _e !== void 0 ? _e : 'ForwardToIndex')
                .replace(/ROBOTS_BEHAVIOR/g, (_f = props.robotsBehavior) !== null && _f !== void 0 ? _f : 'Allow')),
        });
    }
}
exports.RedirectFunction = RedirectFunction;
//# sourceMappingURL=redirect-function.js.map