"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtendedAlarm = void 0;
const aws_cloudwatch_1 = require("aws-cdk-lib/aws-cloudwatch");
const aws_cloudwatch_actions_1 = require("aws-cdk-lib/aws-cloudwatch-actions");
/**
 * Adds convenience properties and methods to Alarm.
 */
class ExtendedAlarm extends aws_cloudwatch_1.Alarm {
    constructor(scope, id, props) {
        super(scope, id, props);
        if (props.alarmTopics) {
            this.addAlarmTopic(...props.alarmTopics);
        }
        if (props.okTopics) {
            this.addOkTopic(...props.okTopics);
        }
        if (props.insufficientDataTopic) {
            this.addInsufficientDataTopic(...props.insufficientDataTopic);
        }
        if (props.alarmActions) {
            this.addAlarmAction(...props.alarmActions);
        }
        if (props.okActions) {
            this.addAlarmAction(...props.okActions);
        }
        if (props.insufficientDataActions) {
            this.addAlarmAction(...props.insufficientDataActions);
        }
    }
    /**
     * Convenience method for adding SNS topics as alarm actions.
     *
     * @param topics the topics to notify
     */
    addAlarmTopic(...topics) {
        this.addAlarmAction(...topics.map(topic => new aws_cloudwatch_actions_1.SnsAction(topic)));
    }
    /**
     * Convenience method for adding SNS topics as ok actions.
     *
     * @param topics the topics to notify
     */
    addOkTopic(...topics) {
        this.addOkAction(...topics.map(topic => new aws_cloudwatch_actions_1.SnsAction(topic)));
    }
    /**
     * Convenience method for adding SNS topics as insufficient data actions.
     *
     * @param topics the topics to notify
     */
    addInsufficientDataTopic(...topics) {
        this.addInsufficientDataAction(...topics.map(topic => new aws_cloudwatch_actions_1.SnsAction(topic)));
    }
}
exports.ExtendedAlarm = ExtendedAlarm;
//# sourceMappingURL=extended-alarm.js.map