"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogMetricFilter = void 0;
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const aws_cdk_lib_1 = require("aws-cdk-lib");
/**
 * MetricFilter that counts the number of records matching the provided pattern.
 */
class LogMetricFilter extends aws_logs_1.MetricFilter {
    /**
     * Creates a new LogMetricFilter
     */
    constructor(scope, id, props) {
        var _a;
        super(scope, id, {
            ...props,
            metricNamespace: (_a = props.metricNamespace) !== null && _a !== void 0 ? _a : 'TrueMark/Logs',
            defaultValue: 0,
            metricValue: '1',
            filterPattern: {
                logPatternString: props.pattern,
            },
        });
    }
    /**
     * Returns the sum metric for this filter.
     *
     * @param period the period over which statistics are applied (default is 5 minutes)
     */
    sumMetric(period) {
        return this.metric({
            statistic: 'Sum',
            period: period !== null && period !== void 0 ? period : aws_cdk_lib_1.Duration.minutes(5),
        });
    }
}
exports.LogMetricFilter = LogMetricFilter;
//# sourceMappingURL=log-metric-filter.js.map