"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MetricAlarmBase = void 0;
const constructs_1 = require("constructs");
const aws_cloudwatch_actions_1 = require("aws-cdk-lib/aws-cloudwatch-actions");
class MetricAlarmBase extends constructs_1.Construct {
    constructor(scope, id, props) {
        super(scope, id);
        this.metric = this.createMetric(props);
        this.alarm = this.createAlarm(this.metric, props);
        this.alarmArn = this.alarm.alarmArn;
        this.alarmName = this.alarm.alarmName;
        this.env = this.alarm.env;
        this.stack = this.alarm.stack;
    }
    /**
     * Notify SNS topics if the alarm fires.
     *
     * @param topics the topics to notify
     */
    addAlarmTopic(...topics) {
        this.alarm.addAlarmAction(...topics.map(topic => new aws_cloudwatch_actions_1.SnsAction(topic)));
    }
    /**
     * Notify SNS topics if the alarm returns from breaching a state into an ok state.
     *
     * @param topics the topics to notify
     */
    addOkTopic(...topics) {
        this.alarm.addOkAction(...topics.map(topic => new aws_cloudwatch_actions_1.SnsAction(topic)));
    }
    /**
     * Notify SNS topics if there is insufficient data to evaluate the alarm.
     *
     * @param topics the topics to notify
     */
    addInsufficientDataTopic(...topics) {
        this.alarm.addInsufficientDataAction(...topics.map(topic => new aws_cloudwatch_actions_1.SnsAction(topic)));
    }
    /**
     * Trigger actions if the alarm fires.
     *
     * @param actions the actions to trigger
     */
    addAlarmAction(...actions) {
        return this.alarm.addAlarmAction(...actions);
    }
    /**
     * Trigger actions if there is insufficient data to evaluate the alarm.
     *
     * @param actions the actions to trigger
     */
    addInsufficientDataAction(...actions) {
        return this.alarm.addInsufficientDataAction(...actions);
    }
    /**
     * Trigger actions if the alarm returns from breaching a state into an ok state.
     *
     * @param actions the actions to trigger
     */
    addOkAction(...actions) {
        return this.alarm.addOkAction(...actions);
    }
    // From IAlarm
    applyRemovalPolicy(policy) {
        this.alarm.applyRemovalPolicy(policy);
    }
    // From IAlarm
    renderAlarmRule() {
        return this.alarm.renderAlarmRule();
    }
}
exports.MetricAlarmBase = MetricAlarmBase;
//# sourceMappingURL=metric-alarm-base.js.map