"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ArtifactBucket = void 0;
const aws_s3_1 = require("aws-cdk-lib/aws-s3");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
/**
 * An S3 bucket for storing artifacts in a pipeline. The created bucket will
 * automatically be destroyed along with its contents when the CDK stack
 * containing it is destroyed. This is not presently the CDK default.
 */
class ArtifactBucket extends aws_s3_1.Bucket {
    constructor(scope, id, props) {
        super(scope, id, {
            autoDeleteObjects: true,
            removalPolicy: aws_cdk_lib_1.RemovalPolicy.DESTROY,
            blockPublicAccess: aws_s3_1.BlockPublicAccess.BLOCK_ALL,
            encryptionKey: props.encryptionKey,
        });
        if (props.accountIds !== undefined) {
            this.addToResourcePolicy(new aws_iam_1.PolicyStatement({
                effect: aws_iam_1.Effect.ALLOW,
                actions: ['s3:Get*', 's3:List*'],
                principals: props.accountIds.map(id => new aws_iam_1.AccountPrincipal(id)),
                resources: [this.arnForObjects('*'), this.bucketArn],
            }));
        }
    }
}
exports.ArtifactBucket = ArtifactBucket;
//# sourceMappingURL=artifact-bucket.js.map