import { INotificationRuleTarget, NotificationRule } from 'aws-cdk-lib/aws-codestarnotifications';
import { Construct } from 'constructs';
import { IPipeline, PipelineNotificationEvents } from 'aws-cdk-lib/aws-codepipeline';
import { ISlackChannelConfiguration } from 'aws-cdk-lib/aws-chatbot';
import { ITopic } from 'aws-cdk-lib/aws-sns';
/**
 * Properties for PipelineNotificationRule.
 */
export interface PipelineNotificationRuleProps {
    /**
     * The events to notify on.
     *
     * @see https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#events-ref-pipeline
     * @default PipelineNotificationRule.PIPELINE_EXECUTION_EVENTS
     */
    readonly events?: string[];
    /**
     * Pipeline source for the events.
     */
    readonly source: IPipeline;
}
/**
 * Configures notifications for a pipeline to a ChatOps Slack channel.
 */
export declare class PipelineNotificationRule extends Construct {
    static readonly ACTION_EXECUTION_EVENTS: PipelineNotificationEvents[];
    static readonly STAGE_EXECUTION_EVENTS: PipelineNotificationEvents[];
    static readonly PIPELINE_EXECUTION_EVENTS: PipelineNotificationEvents[];
    static readonly MANUAL_APPROVAL_EVENTS: PipelineNotificationEvents[];
    static readonly ALL_NOTIFICATION_EVENTS: PipelineNotificationEvents[];
    static readonly DEFAULT_EVENTS: PipelineNotificationEvents[];
    readonly notificationRule: NotificationRule;
    readonly targets: INotificationRuleTarget[];
    constructor(scope: Construct, id: string, props: PipelineNotificationRuleProps);
    addSlackChannelArn(id: string, slackChannelArn: string): ISlackChannelConfiguration;
    addSlackChannel(slackChannel: ISlackChannelConfiguration): void;
    addTopicArn(id: string, topicArn: string): ITopic;
    addTopic(topic: ITopic): void;
}
