"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PipelineNotificationRule = void 0;
const aws_codestarnotifications_1 = require("aws-cdk-lib/aws-codestarnotifications");
const constructs_1 = require("constructs");
const aws_codepipeline_1 = require("aws-cdk-lib/aws-codepipeline");
const aws_chatbot_1 = require("aws-cdk-lib/aws-chatbot");
const aws_sns_1 = require("aws-cdk-lib/aws-sns");
/**
 * Configures notifications for a pipeline to a ChatOps Slack channel.
 */
class PipelineNotificationRule extends constructs_1.Construct {
    constructor(scope, id, props) {
        var _a;
        super(scope, id);
        this.targets = [];
        this.notificationRule = new aws_codestarnotifications_1.NotificationRule(this, 'Rule', {
            source: props.source,
            events: (_a = props.events) !== null && _a !== void 0 ? _a : PipelineNotificationRule.DEFAULT_EVENTS,
        });
    }
    addSlackChannelArn(id, slackChannelArn) {
        const slackChannel = aws_chatbot_1.SlackChannelConfiguration.fromSlackChannelConfigurationArn(this, id, slackChannelArn);
        this.notificationRule.addTarget(slackChannel);
        return slackChannel;
    }
    addSlackChannel(slackChannel) {
        this.targets.push(slackChannel);
        this.notificationRule.addTarget(slackChannel);
    }
    addTopicArn(id, topicArn) {
        const topic = aws_sns_1.Topic.fromTopicArn(this, id, topicArn);
        this.notificationRule.addTarget(topic);
        return topic;
    }
    addTopic(topic) {
        this.targets.push(topic);
        this.notificationRule.addTarget(topic);
    }
}
exports.PipelineNotificationRule = PipelineNotificationRule;
PipelineNotificationRule.ACTION_EXECUTION_EVENTS = [
    aws_codepipeline_1.PipelineNotificationEvents.ACTION_EXECUTION_SUCCEEDED,
    aws_codepipeline_1.PipelineNotificationEvents.ACTION_EXECUTION_FAILED,
    aws_codepipeline_1.PipelineNotificationEvents.ACTION_EXECUTION_CANCELED,
    aws_codepipeline_1.PipelineNotificationEvents.ACTION_EXECUTION_STARTED,
];
PipelineNotificationRule.STAGE_EXECUTION_EVENTS = [
    aws_codepipeline_1.PipelineNotificationEvents.STAGE_EXECUTION_STARTED,
    aws_codepipeline_1.PipelineNotificationEvents.STAGE_EXECUTION_SUCCEEDED,
    aws_codepipeline_1.PipelineNotificationEvents.STAGE_EXECUTION_RESUMED,
    aws_codepipeline_1.PipelineNotificationEvents.STAGE_EXECUTION_CANCELED,
    aws_codepipeline_1.PipelineNotificationEvents.STAGE_EXECUTION_FAILED,
];
PipelineNotificationRule.PIPELINE_EXECUTION_EVENTS = [
    aws_codepipeline_1.PipelineNotificationEvents.PIPELINE_EXECUTION_FAILED,
    aws_codepipeline_1.PipelineNotificationEvents.PIPELINE_EXECUTION_CANCELED,
    aws_codepipeline_1.PipelineNotificationEvents.PIPELINE_EXECUTION_STARTED,
    aws_codepipeline_1.PipelineNotificationEvents.PIPELINE_EXECUTION_RESUMED,
    aws_codepipeline_1.PipelineNotificationEvents.PIPELINE_EXECUTION_SUCCEEDED,
    aws_codepipeline_1.PipelineNotificationEvents.PIPELINE_EXECUTION_SUPERSEDED,
];
PipelineNotificationRule.MANUAL_APPROVAL_EVENTS = [
    aws_codepipeline_1.PipelineNotificationEvents.MANUAL_APPROVAL_NEEDED,
    aws_codepipeline_1.PipelineNotificationEvents.MANUAL_APPROVAL_FAILED,
    aws_codepipeline_1.PipelineNotificationEvents.MANUAL_APPROVAL_SUCCEEDED,
];
PipelineNotificationRule.ALL_NOTIFICATION_EVENTS = [
    ...PipelineNotificationRule.ACTION_EXECUTION_EVENTS,
    ...PipelineNotificationRule.STAGE_EXECUTION_EVENTS,
    ...PipelineNotificationRule.PIPELINE_EXECUTION_EVENTS,
    ...PipelineNotificationRule.MANUAL_APPROVAL_EVENTS,
];
PipelineNotificationRule.DEFAULT_EVENTS = [
    ...PipelineNotificationRule.PIPELINE_EXECUTION_EVENTS,
    ...PipelineNotificationRule.MANUAL_APPROVAL_EVENTS,
    aws_codepipeline_1.PipelineNotificationEvents.STAGE_EXECUTION_SUCCEEDED,
];
//# sourceMappingURL=pipeline-notification-rule.js.map