import { Construct } from 'constructs';
import { Duration } from 'aws-cdk-lib';
import { AwsCustomResource } from 'aws-cdk-lib/custom-resources';
export type BatchWriteItemKey = {
    Key: Record<string, any>;
};
export type BatchWriteItemItem = {
    Item: Record<string, any>;
};
export type BatchWriteItemRequest = {
    DeleteRequest: BatchWriteItemKey;
} | {
    PutRequest: BatchWriteItemItem;
};
export type BatchWriteItemRequestItems = {
    RequestItems: Record<string, BatchWriteItemRequest[]>;
};
/**
 * Properties for BatchWriteItem
 */
export interface BatchWriteItemProps {
    /**
     * The items to write.
     */
    readonly items: BatchWriteItemRequestItems;
    /**
     * The timeout for the Lambda function. Default is 2 minutes.
     *
     * @default Duration.minutes(2)
     */
    readonly timeout?: Duration;
    /**
     * Log retention days. The default is 5.
     */
    readonly logRetention?: number;
}
export declare class BatchWriteItem extends Construct {
    readonly resource: AwsCustomResource;
    constructor(scope: Construct, id: string, props: BatchWriteItemProps);
}
