"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BatchWriteItem = void 0;
const constructs_1 = require("constructs");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const custom_resources_1 = require("aws-cdk-lib/custom-resources");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
class BatchWriteItem extends constructs_1.Construct {
    constructor(scope, id, props) {
        var _a, _b;
        super(scope, id);
        const call = {
            service: 'DynamoDB',
            action: 'batchWriteItem',
            parameters: props.items,
            physicalResourceId: custom_resources_1.PhysicalResourceId.of(Date.now().toString()),
        };
        const tableNames = Object.keys(props.items.RequestItems);
        this.resource = new custom_resources_1.AwsCustomResource(this, 'Default', {
            onUpdate: call,
            logRetention: (_a = props.logRetention) !== null && _a !== void 0 ? _a : aws_logs_1.RetentionDays.FIVE_DAYS,
            installLatestAwsSdk: false,
            policy: {
                statements: [
                    new aws_iam_1.PolicyStatement({
                        resources: tableNames.map(name => {
                            return aws_cdk_lib_1.Stack.of(this).formatArn({
                                service: 'dynamodb',
                                resource: 'table',
                                resourceName: name,
                            });
                        }),
                        actions: ['dynamodb:BatchWriteItem'],
                        effect: aws_iam_1.Effect.ALLOW,
                    }),
                ],
            },
            timeout: (_b = props.timeout) !== null && _b !== void 0 ? _b : aws_cdk_lib_1.Duration.minutes(2),
        });
    }
}
exports.BatchWriteItem = BatchWriteItem;
// {
//   "RequestItems": {
//   "string" : [
//     {
//       "DeleteRequest": {
//         "Key": {
//           "string" : {
//             "B": blob,
//             "BOOL": boolean,
//             "BS": [ blob ],
//             "L": [
//               "AttributeValue"
//             ],
//             "M": {
//               "string" : "AttributeValue"
//             },
//             "N": "string",
//             "NS": [ "string" ],
//             "NULL": boolean,
//             "S": "string",
//             "SS": [ "string" ]
//           }
//         }
//       },
//       "PutRequest": {
//         "Item": {
//           "string" : {
//             "B": blob,
//             "BOOL": boolean,
//             "BS": [ blob ],
//             "L": [
//               "AttributeValue"
//             ],
//             "M": {
//               "string" : "AttributeValue"
//             },
//             "N": "string",
//             "NS": [ "string" ],
//             "NULL": boolean,
//             "S": "string",
//             "SS": [ "string" ]
//           }
//         }
//       }
//     }
//   ]
// },
//
// RequestItems: {
//   "TABLE_NAME": [
//     {
//       PutRequest: {
//         Item: {
//           "KEY": { "N": "KEY_VALUE" },
//           "ATTRIBUTE_1": { "S": "ATTRIBUTE_1_VALUE" },
//           "ATTRIBUTE_2": { "N": "ATTRIBUTE_2_VALUE" }
//         }
//       }
//     },
//     {
//       PutRequest: {
//         Item: {
//           "KEY": { "N": "KEY_VALUE" },
//           "ATTRIBUTE_1": { "S": "ATTRIBUTE_1_VALUE" },
//           "ATTRIBUTE_2": { "N": "ATTRIBUTE_2_VALUE" }
//         }
//       }
//     }
//   ]
// }
//# sourceMappingURL=batch-write-item.js.map