import { AwsCustomResource } from 'aws-cdk-lib/custom-resources';
import { Construct } from 'constructs';
import { Duration } from 'aws-cdk-lib';
/**
 * Properties for PutItem.
 */
export interface PutItemProps {
    /**
     * The name of the DynamoDB table to write to.
     */
    readonly tableName: string;
    /**
     * The item to store.
     */
    readonly item: any;
    /**
     * The timeout for the Lambda function. Default is 2 minutes.
     *
     * @default Duration.minutes(2)
     */
    readonly timeout?: Duration;
    /**
     * Log retention days. The default is 5.
     */
    readonly logRetention?: number;
}
/**
 * Custom resource to insert data into a DynamoDB table. This class is intended to be used with
 * the marshall command @aws-sdk/util-dynamodb as an alternative to using DynamoPutItem.
 */
export declare class PutItem extends Construct {
    readonly resource: AwsCustomResource;
    constructor(scope: Construct, id: string, props: PutItemProps);
}
