"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PutItem = void 0;
const custom_resources_1 = require("aws-cdk-lib/custom-resources");
const constructs_1 = require("constructs");
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
/**
 * Custom resource to insert data into a DynamoDB table. This class is intended to be used with
 * the marshall command @aws-sdk/util-dynamodb as an alternative to using DynamoPutItem.
 */
class PutItem extends constructs_1.Construct {
    constructor(scope, id, props) {
        var _a, _b;
        super(scope, id);
        const call = {
            service: 'DynamoDB',
            action: 'putItem',
            parameters: {
                TableName: props.tableName,
                Item: props.item,
            },
            physicalResourceId: custom_resources_1.PhysicalResourceId.of(Date.now().toString()),
        };
        this.resource = new custom_resources_1.AwsCustomResource(this, 'Default', {
            onUpdate: call,
            logRetention: (_a = props.logRetention) !== null && _a !== void 0 ? _a : aws_logs_1.RetentionDays.FIVE_DAYS,
            installLatestAwsSdk: false,
            policy: {
                statements: [
                    new aws_iam_1.PolicyStatement({
                        resources: [
                            aws_cdk_lib_1.Stack.of(this).formatArn({
                                service: 'dynamodb',
                                resource: 'table',
                                resourceName: props.tableName,
                            }),
                        ],
                        actions: ['dynamodb:PutItem'],
                        effect: aws_iam_1.Effect.ALLOW,
                    }),
                ],
            },
            timeout: (_b = props.timeout) !== null && _b !== void 0 ? _b : aws_cdk_lib_1.Duration.minutes(2),
        });
    }
}
exports.PutItem = PutItem;
//# sourceMappingURL=put-item.js.map