import { Duration } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { BatchWriteItem } from './batch-write-item';
/**
 * Properties for PutItems.
 */
export interface PutItemsProps {
    /**
     * The name of the DynamoDB table to write to.
     */
    readonly tableName: string;
    /**
     * The items to store.
     */
    readonly items: any[];
    /**
     * The timeout for the Lambda function. Default is 2 minutes.
     *
     * @default Duration.minutes(2)
     */
    readonly timeout?: Duration;
    /**
     * Log retention days. The default is 5.
     */
    readonly logRetention?: number;
}
/**
 * Custom resource to insert multiple items into a DynamoDB table.
 */
export declare class PutItems extends BatchWriteItem {
    constructor(scope: Construct, id: string, props: PutItemsProps);
}
