"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableAlarms = void 0;
const aws_monitoring_1 = require("../../aws-monitoring");
/**
 * Creates CloudWatch alarms for DynamoDB Tables.
 */
class TableAlarms extends aws_monitoring_1.AlarmsBase {
    constructor(scope, id, props) {
        var _a, _b, _c, _d;
        super(scope, id, props);
        this.createAlarms = (_a = props.createAlarms) !== null && _a !== void 0 ? _a : true;
        if (this.createAlarms) {
            if (this.monitoringFacade === undefined) {
                throw new Error('monitoringFacade is undefined');
            }
            this.monitoringFacade.monitorDynamoTable({
                table: props.table,
                addToSummaryDashboard: (_b = props.addToSummaryDashboard) !== null && _b !== void 0 ? _b : true,
                addToDetailDashboard: (_c = props.addToDetailDashboard) !== null && _c !== void 0 ? _c : true,
                addToAlarmDashboard: (_d = props.addToAlarmDashboard) !== null && _d !== void 0 ? _d : true,
                addConsumedReadCapacityAlarm: this.toRecord('maxConsumedReadCapacity', 'maxConsumedCapacityUnits'),
                addConsumedWriteCapacityAlarm: this.toRecord('maxConsumedWriteCapacity', 'maxConsumedCapacityUnits'),
                addReadThrottledEventsCountAlarm: this.toRecord('maxReadThrottledEventsCount', 'maxThrottledEventsThreshold', 0),
                addWriteThrottledEventsCountAlarm: this.toRecord('maxWriteThrottledEventsCount', 'maxThrottledEventsThreshold', 0),
                addSystemErrorCountAlarm: this.toRecord('maxSystemErrorCount', 'maxErrorCount', 0),
                addAverageSuccessfulGetRecordsLatencyAlarm: this.toRecord('averageSuccessfulGetRecordsLatency', 'maxLatency'),
                addAverageSuccessfulQueryLatencyAlarm: this.toRecord('averageSuccessfulQueryLatency', 'maxLatency'),
                addAverageSuccessfulScanLatencyAlarm: this.toRecord('averageSuccessfulScanLatency', 'maxLatency'),
                addAverageSuccessfulPutItemLatencyAlarm: this.toRecord('averageSuccessfulPutItemLatency', 'maxLatency'),
                addAverageSuccessfulGetItemLatencyAlarm: this.toRecord('averageSuccessfulGetItemLatency', 'maxLatency'),
                addAverageSuccessfulUpdateItemLatencyAlarm: this.toRecord('averageSuccessfulUpdateItemLatency', 'maxLatency'),
                addAverageSuccessfulDeleteItemLatencyAlarm: this.toRecord('averageSuccessfulDeleteItemLatency', 'maxLatency'),
                addAverageSuccessfulBatchGetItemLatencyAlarm: this.toRecord('averageSuccessfulBatchGetItemLatency', 'maxLatency'),
                addAverageSuccessfulBatchWriteItemLatencyAlarm: this.toRecord('averageSuccessfulBatchWriteItemLatency', 'maxLatency'),
            });
        }
    }
    addGlobalSecondaryIndexMonitoring(indexName) {
        if (this.createAlarms) {
            if (this.monitoringFacade === undefined) {
                throw new Error('monitoringFacade is undefined');
            }
            this.monitoringFacade.monitorDynamoTableGlobalSecondaryIndex({
                table: this.props.table,
                globalSecondaryIndexName: indexName,
                addToSummaryDashboard: this.props.addToSummaryDashboard,
                addToDetailDashboard: this.props.addToDetailDashboard,
                addToAlarmDashboard: this.props.addToAlarmDashboard,
            });
        }
    }
}
exports.TableAlarms = TableAlarms;
//# sourceMappingURL=table-alarms.js.map