"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardApplicationFargateService = void 0;
const standard_fargate_service_1 = require("./standard-fargate-service");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_elasticloadbalancingv2_1 = require("aws-cdk-lib/aws-elasticloadbalancingv2");
const aws_route53_1 = require("aws-cdk-lib/aws-route53");
const aws_route53_2 = require("../../aws-route53");
const aws_route53_targets_1 = require("aws-cdk-lib/aws-route53-targets");
/**
 * Creates an ECS Fargate service and maps it to an Application Load Balancer (ALB).
 */
class StandardApplicationFargateService extends standard_fargate_service_1.StandardFargateService {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r;
        super(scope, id, props);
        let stickinessCookieDuration = (_a = props.stickinessCookieDuration) !== null && _a !== void 0 ? _a : aws_cdk_lib_1.Duration.days(1);
        if (stickinessCookieDuration.toSeconds() === 0) {
            stickinessCookieDuration = undefined;
        }
        let stickinessCookieName;
        if (stickinessCookieDuration !== undefined) {
            stickinessCookieName = (_b = props.stickinessCookieName) !== null && _b !== void 0 ? _b : 'lb_affinity';
        }
        let slowStart = (_c = props.slowStart) !== null && _c !== void 0 ? _c : aws_cdk_lib_1.Duration.seconds(30);
        if (slowStart.toSeconds() === 0) {
            slowStart = undefined;
        }
        const targetGroup = new aws_elasticloadbalancingv2_1.ApplicationTargetGroup(this, 'TargetGroup', {
            targets: [this.service],
            vpc: props.cluster.vpc,
            port: this.port,
            protocol: (_d = props.applicationProtocol) !== null && _d !== void 0 ? _d : aws_elasticloadbalancingv2_1.ApplicationProtocol.HTTP,
            deregistrationDelay: (_e = props.deregistrationDelay) !== null && _e !== void 0 ? _e : aws_cdk_lib_1.Duration.seconds(10),
            slowStart,
            healthCheck: {
                enabled: true,
                interval: (_f = props.healthCheckInterval) !== null && _f !== void 0 ? _f : aws_cdk_lib_1.Duration.seconds(10),
                path: (_g = props.healthCheckPath) !== null && _g !== void 0 ? _g : '/health',
                timeout: (_h = props.healthCheckTimeout) !== null && _h !== void 0 ? _h : aws_cdk_lib_1.Duration.seconds(3),
                healthyThresholdCount: (_j = props.healthyThresholdCount) !== null && _j !== void 0 ? _j : 2,
                unhealthyThresholdCount: (_k = props.unhealthyThresholdCount) !== null && _k !== void 0 ? _k : 2,
                healthyHttpCodes: (_l = props.healthyHttpCodes) !== null && _l !== void 0 ? _l : '200-299',
            },
            stickinessCookieName,
            stickinessCookieDuration,
            loadBalancingAlgorithmType: (_m = props.loadBalancingAlgorithmType) !== null && _m !== void 0 ? _m : aws_elasticloadbalancingv2_1.TargetGroupLoadBalancingAlgorithmType.ROUND_ROBIN,
        });
        if (props.scaleRequestPerTarget !== undefined) {
            this.scaling.scaleOnRequestCount('RequestCountScaling', {
                scaleInCooldown: this.scaleInCooldown,
                scaleOutCooldown: this.scaleOutCooldown,
                targetGroup,
                requestsPerTarget: props.scaleRequestPerTarget,
            });
        }
        const targetGroupConditions = [];
        targetGroupConditions.push(aws_elasticloadbalancingv2_1.ListenerCondition.pathPatterns((_o = props.pathPattern) !== null && _o !== void 0 ? _o : ['/*']));
        if (props.domainName !== undefined) {
            targetGroupConditions.push(aws_elasticloadbalancingv2_1.ListenerCondition.hostHeaders([
                props.domainName,
                ...((_p = props.domainNames) !== null && _p !== void 0 ? _p : []),
            ]));
        }
        let loadBalancer;
        if (typeof props.loadBalancer === 'string') {
            if (props.loadBalancer.startsWith('arn:')) {
                loadBalancer = aws_elasticloadbalancingv2_1.ApplicationLoadBalancer.fromLookup(this, 'LoadBalancer', {
                    loadBalancerArn: props.loadBalancer,
                });
            }
            else {
                loadBalancer = aws_elasticloadbalancingv2_1.ApplicationLoadBalancer.fromLookup(this, 'LoadBalancer', {
                    loadBalancerTags: {
                        Name: props.loadBalancer,
                    },
                });
            }
        }
        else {
            loadBalancer = props.loadBalancer;
        }
        const listener = aws_elasticloadbalancingv2_1.ApplicationListener.fromLookup(this, 'Listener', {
            loadBalancerArn: loadBalancer.loadBalancerArn,
            listenerProtocol: (_q = props.listenerProtocol) !== null && _q !== void 0 ? _q : aws_elasticloadbalancingv2_1.ApplicationProtocol.HTTPS,
        });
        listener.addTargetGroups(`${id}TargetGroups`, {
            targetGroups: [targetGroup],
            conditions: targetGroupConditions,
            priority: (_r = props.targetGroupPriority) !== null && _r !== void 0 ? _r : 1,
        });
        if (props.domainName !== undefined &&
            props.domainZone !== undefined &&
            !props.skipCreateRoute53Records) {
            this.domainName = aws_route53_2.DomainName.fromFqdn(props.domainName, props.domainZone);
            this.route53Record = this.domainName.createARecord(this, aws_route53_1.RecordTarget.fromAlias(new aws_route53_targets_1.LoadBalancerTarget(loadBalancer)));
        }
        this.loadBalancer = loadBalancer;
        this.listener = listener;
    }
}
exports.StandardApplicationFargateService = StandardApplicationFargateService;
//# sourceMappingURL=standard-application-fargate-service.js.map