"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardFargateService = void 0;
const aws_ecs_1 = require("aws-cdk-lib/aws-ecs");
const aws_ec2_1 = require("aws-cdk-lib/aws-ec2");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
const aws_cdk_1 = require("../../aws-cdk");
const truemark_1 = require("../../truemark");
/**
 * Standard class for creating a FargateService. It's recommended to use the StandardApplicationFargateService or
 * StandardNetworkFargateService instead of this class.
 */
class StandardFargateService extends aws_cdk_1.ExtendedConstruct {
    resolveLogGroup(scope, props) {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        if ((_b = (_a = props.logConfiguration) === null || _a === void 0 ? void 0 : _a.enabled) !== null && _b !== void 0 ? _b : true) {
            return new aws_logs_1.LogGroup(scope, 'LogGroup', {
                retention: (_d = (_c = props.logConfiguration) === null || _c === void 0 ? void 0 : _c.retention) !== null && _d !== void 0 ? _d : aws_logs_1.RetentionDays.FIVE_DAYS,
                logGroupName: (_e = props.logConfiguration) === null || _e === void 0 ? void 0 : _e.logGroupName,
                encryptionKey: (_f = props.logConfiguration) === null || _f === void 0 ? void 0 : _f.encryptionKey,
                removalPolicy: (_h = (_g = props.logConfiguration) === null || _g === void 0 ? void 0 : _g.removalPolicy) !== null && _h !== void 0 ? _h : aws_cdk_lib_1.RemovalPolicy.DESTROY,
            });
        }
        return undefined;
    }
    resolveLogDriver(scope, props, logGroup) {
        var _a, _b;
        if ((_b = (_a = props.logConfiguration) === null || _a === void 0 ? void 0 : _a.enabled) !== null && _b !== void 0 ? _b : true) {
            return aws_ecs_1.LogDriver.awsLogs({
                streamPrefix: scope.node.id,
                logGroup,
            });
        }
        return undefined;
    }
    resolveVpcSubnets(scope, props) {
        if (props.vpcSubnets === undefined) {
            return {
                subnetType: aws_ec2_1.SubnetType.PRIVATE_WITH_EGRESS,
            };
        }
        return props.vpcSubnets;
    }
    resolvedCapacityProviderStrategies(props) {
        const strategies = [];
        if (props.capacityWeight !== undefined ||
            props.capacityBase !== undefined) {
            strategies.push({
                capacityProvider: 'FARGATE',
                base: props.capacityBase,
                weight: props.capacityWeight,
            });
        }
        if (props.spotCapacityWeight !== undefined ||
            props.spotCapacityBase !== undefined) {
            strategies.push({
                capacityProvider: 'FARGATE_SPOT',
                base: props.spotCapacityBase,
                weight: props.spotCapacityWeight,
            });
        }
        return strategies.length > 0 ? strategies : undefined;
    }
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x;
        super(scope, id, {
            standardTags: aws_cdk_1.StandardTags.merge(props.standardTags, truemark_1.LibStandardTags),
        });
        const taskDefinition = new aws_ecs_1.FargateTaskDefinition(this, 'Resource', {
            cpu: (_a = props.cpu) !== null && _a !== void 0 ? _a : 2048,
            memoryLimitMiB: (_b = props.memoryLimitMiB) !== null && _b !== void 0 ? _b : 4096,
            ephemeralStorageGiB: props.ephemeralStorageGiB,
            runtimePlatform: {
                operatingSystemFamily: aws_ecs_1.OperatingSystemFamily.LINUX,
                cpuArchitecture: (_c = props.cpuArchitecture) !== null && _c !== void 0 ? _c : aws_ecs_1.CpuArchitecture.ARM64,
            },
        });
        if (!props.disableXray) {
            taskDefinition.addToTaskRolePolicy(new aws_iam_1.PolicyStatement({
                resources: ['*'],
                actions: ['cloudwatch:PutMetricData'],
            }));
        }
        const logGroup = this.resolveLogGroup(this, props);
        const logging = this.resolveLogDriver(this, props, logGroup);
        const port = (_d = props.port) !== null && _d !== void 0 ? _d : 8080;
        const protocol = (_e = props.protocol) !== null && _e !== void 0 ? _e : aws_ecs_1.Protocol.TCP;
        taskDefinition.addContainer('Container', {
            image: props.image,
            portMappings: [
                {
                    containerPort: port,
                    hostPort: port,
                    protocol,
                },
            ],
            logging,
            environment: props.environment,
            dockerLabels: props.dockerLabels,
            secrets: props.secrets,
        });
        // TODO Otel Collector
        const vpcSubnets = this.resolveVpcSubnets(this, props);
        const desiredCount = (_g = (_f = props.desiredCount) !== null && _f !== void 0 ? _f : props.minCapacity) !== null && _g !== void 0 ? _g : 1;
        const capacityProviderStrategies = this.resolvedCapacityProviderStrategies(props);
        const securityGroup = new aws_ec2_1.SecurityGroup(this, 'SecurityGroup', {
            vpc: props.cluster.vpc,
            allowAllIpv6Outbound: (_h = props.allowAllIpv6Outbound) !== null && _h !== void 0 ? _h : false,
            allowAllOutbound: true,
        });
        const service = new aws_ecs_1.FargateService(this, 'Default', {
            cluster: props.cluster,
            taskDefinition,
            serviceName: props.serviceName,
            maxHealthyPercent: (_j = props.maxHealthyPercent) !== null && _j !== void 0 ? _j : 200,
            minHealthyPercent: (_k = props.minHealthyPercent) !== null && _k !== void 0 ? _k : 100,
            desiredCount,
            circuitBreaker: {
                rollback: (_l = props.enableRollback) !== null && _l !== void 0 ? _l : true,
            },
            deploymentController: {
                type: (_m = props.deploymentControllerType) !== null && _m !== void 0 ? _m : aws_ecs_1.DeploymentControllerType.ECS,
            },
            vpcSubnets,
            platformVersion: (_o = props.platformVersion) !== null && _o !== void 0 ? _o : aws_ecs_1.FargatePlatformVersion.LATEST,
            enableExecuteCommand: (_p = props.enableExecuteCommand) !== null && _p !== void 0 ? _p : true,
            assignPublicIp: (_q = props.assignPublicIp) !== null && _q !== void 0 ? _q : false,
            enableECSManagedTags: (_r = props.enableECSManagedTags) !== null && _r !== void 0 ? _r : true,
            healthCheckGracePeriod: (_s = props.healthCheckGracePeriod) !== null && _s !== void 0 ? _s : aws_cdk_lib_1.Duration.seconds(30),
            capacityProviderStrategies,
            securityGroups: [securityGroup],
        });
        const scaling = service.autoScaleTaskCount({
            minCapacity: (_t = props.minCapacity) !== null && _t !== void 0 ? _t : 1,
            maxCapacity: (_u = props.maxCapacity) !== null && _u !== void 0 ? _u : 2,
        });
        const scaleInCooldown = (_v = props.scaleInCooldown) !== null && _v !== void 0 ? _v : aws_cdk_lib_1.Duration.seconds(10);
        const scaleOutCooldown = (_w = props.scaleOutCooldown) !== null && _w !== void 0 ? _w : aws_cdk_lib_1.Duration.seconds(60);
        if (props.scaleCpuTargetUtilizationPercent !== 0) {
            scaling.scaleOnCpuUtilization('CpuScaling', {
                scaleInCooldown,
                scaleOutCooldown,
                targetUtilizationPercent: (_x = props.scaleCpuTargetUtilizationPercent) !== null && _x !== void 0 ? _x : 60,
            });
        }
        if (props.scaleMemoryTargetUtilizationPercent !== undefined) {
            scaling.scaleOnMemoryUtilization('MemoryScaling', {
                scaleInCooldown,
                scaleOutCooldown,
                targetUtilizationPercent: props.scaleMemoryTargetUtilizationPercent,
            });
        }
        this.port = port;
        this.taskDefinition = taskDefinition;
        this.logGroup = logGroup;
        this.service = service;
        this.scaling = scaling;
        this.scaleInCooldown = scaleInCooldown;
        this.scaleOutCooldown = scaleOutCooldown;
        this.securityGroup = securityGroup;
    }
    /**
     * Helper method to conduct scaling based on tracking custom metrics.
     *
     * @param id the id to give the scaling
     * @param metric the metric to track
     * @param targetValue the target value
     */
    scaleToTrackCustomMetric(id, metric, targetValue) {
        this.scaling.scaleToTrackCustomMetric(id, {
            scaleInCooldown: this.scaleInCooldown,
            scaleOutCooldown: this.scaleOutCooldown,
            metric,
            targetValue,
        });
    }
    /**
     * Convenience method to scale based on a metric.
     *
     * @param id the id to give the scaling policy
     * @param props scaling properties
     */
    scaleOnMetric(id, props) {
        this.scaling.scaleOnMetric(id, props);
    }
    /**
     * Convenience method to scale based on a schedule.
     *
     * @param id the id to give the scaling policy
     * @param props scaling properties
     */
    scaleOnSchedule(id, props) {
        this.scaling.scaleOnSchedule(id, props);
    }
}
exports.StandardFargateService = StandardFargateService;
//# sourceMappingURL=standard-fargate-service.js.map