"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardNetworkFargateService = void 0;
const standard_fargate_service_1 = require("./standard-fargate-service");
const aws_elasticloadbalancingv2_1 = require("aws-cdk-lib/aws-elasticloadbalancingv2");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_route53_1 = require("aws-cdk-lib/aws-route53");
const aws_route53_2 = require("../../aws-route53");
const aws_route53_targets_1 = require("aws-cdk-lib/aws-route53-targets");
/**
 * Creates an ECS Fargate service and maps it to a Network Load Balancer (NLB).
 */
class StandardNetworkFargateService extends standard_fargate_service_1.StandardFargateService {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
        super(scope, id, props);
        const targetGroup = new aws_elasticloadbalancingv2_1.NetworkTargetGroup(this, 'TargetGroup', {
            targets: [this.service],
            vpc: props.cluster.vpc,
            port: this.port,
            connectionTermination: (_a = props.connectionTermination) !== null && _a !== void 0 ? _a : false,
            deregistrationDelay: (_b = props.deregistrationDelay) !== null && _b !== void 0 ? _b : aws_cdk_lib_1.Duration.seconds(10),
            healthCheck: {
                enabled: (_c = props.healthCheckEnabled) !== null && _c !== void 0 ? _c : true,
                healthyThresholdCount: (_d = props.healthyThresholdCount) !== null && _d !== void 0 ? _d : 2,
                interval: (_e = props.healthCheckInterval) !== null && _e !== void 0 ? _e : aws_cdk_lib_1.Duration.seconds(10),
                protocol: (_f = props.healthCheckProtocol) !== null && _f !== void 0 ? _f : aws_elasticloadbalancingv2_1.Protocol.TCP,
                timeout: (_g = props.healthCheckTimeout) !== null && _g !== void 0 ? _g : aws_cdk_lib_1.Duration.seconds(3),
                unhealthyThresholdCount: (_h = props.unhealthyThresholdCount) !== null && _h !== void 0 ? _h : 2,
            },
            protocol: (_j = props.networkProtocol) !== null && _j !== void 0 ? _j : aws_elasticloadbalancingv2_1.Protocol.TCP,
            proxyProtocolV2: (_k = props.proxyProtocolV2) !== null && _k !== void 0 ? _k : false,
        });
        let loadBalancer;
        if (typeof props.loadBalancer === 'string') {
            if (props.loadBalancer.startsWith('arn:')) {
                loadBalancer = aws_elasticloadbalancingv2_1.NetworkLoadBalancer.fromLookup(this, 'LoadBalancer', {
                    loadBalancerArn: props.loadBalancer,
                });
            }
            else {
                loadBalancer = aws_elasticloadbalancingv2_1.NetworkLoadBalancer.fromLookup(this, 'LoadBalancer', {
                    loadBalancerTags: {
                        Name: props.loadBalancer,
                    },
                });
            }
        }
        else {
            loadBalancer = props.loadBalancer;
        }
        const listener = aws_elasticloadbalancingv2_1.NetworkListener.fromLookup(this, 'Listener', {
            loadBalancerArn: loadBalancer.loadBalancerArn,
            listenerPort: props.listenerPort,
        });
        targetGroup.registerListener(listener);
        if (props.domainZone !== undefined) {
            this.domainName = new aws_route53_2.DomainName({
                prefix: (_l = props.domainPrefix) !== null && _l !== void 0 ? _l : '',
                zone: props.domainZone,
            });
            this.route53Record = this.domainName.createARecord(this, aws_route53_1.RecordTarget.fromAlias(new aws_route53_targets_1.LoadBalancerTarget(loadBalancer)));
        }
        this.loadBalancer = loadBalancer;
        this.listener = listener;
    }
}
exports.StandardNetworkFargateService = StandardNetworkFargateService;
//# sourceMappingURL=standard-network-fargate-service.js.map