"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtendedGoFunction = void 0;
const function_alarms_1 = require("./function-alarms");
const function_deployment_1 = require("./function-deployment");
const aws_lambda_go_alpha_1 = require("@aws-cdk/aws-lambda-go-alpha");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const aws_lambda_1 = require("aws-cdk-lib/aws-lambda");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const process = require("process");
/**
 * Extended version of the GoFunction that supports alarms and deployments.
 */
class ExtendedGoFunction extends aws_lambda_go_alpha_1.GoFunction {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f;
        super(scope, id, {
            logRetention: aws_logs_1.RetentionDays.THREE_DAYS,
            architecture: aws_lambda_1.Architecture.ARM_64,
            memorySize: 768,
            timeout: aws_cdk_lib_1.Duration.seconds(30),
            runtime: aws_lambda_1.Runtime.PROVIDED_AL2023,
            ...props,
            bundling: {
                environment: {
                    GOOS: process.env.GOOS || 'linux',
                    GOARCH: process.env.GOARCH || 'arm64',
                    ...props.environment,
                },
                ...props.bundling,
            },
        });
        this.alarms = new function_alarms_1.FunctionAlarms(this, 'Alarms', {
            function: this,
            logGroup: this.logGroup,
            ...props,
        });
        if ((_b = (_a = props.deploymentOptions) === null || _a === void 0 ? void 0 : _a.createDeployment) !== null && _b !== void 0 ? _b : true) {
            this.deployment = new function_deployment_1.FunctionDeployment(this, 'Deployment', {
                ...props.deploymentOptions,
                function: this,
            });
            if ((_d = (_c = props.deploymentOptions) === null || _c === void 0 ? void 0 : _c.includeCriticalAlarms) !== null && _d !== void 0 ? _d : true) {
                this.deployment.addAlarms(...this.alarms.getCriticalAlarms());
            }
            if ((_f = (_e = props.deploymentOptions) === null || _e === void 0 ? void 0 : _e.includeWarningAlarms) !== null && _f !== void 0 ? _f : false) {
                this.deployment.addAlarms(...this.alarms.getWarningAlarms());
            }
        }
    }
}
exports.ExtendedGoFunction = ExtendedGoFunction;
//# sourceMappingURL=extended-go-function.js.map