"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtendedNodejsFunction = void 0;
const function_alarms_1 = require("./function-alarms");
const function_deployment_1 = require("./function-deployment");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const aws_lambda_1 = require("aws-cdk-lib/aws-lambda");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const fs = require("fs");
const path = require("path");
const aws_lambda_nodejs_1 = require("aws-cdk-lib/aws-lambda-nodejs");
class ExtendedNodejsFunction extends aws_lambda_nodejs_1.NodejsFunction {
    static findDepsLockFile(entry) {
        if (entry !== undefined) {
            const depsLockFilePath = path.join(path.dirname(entry), 'package-lock.json');
            if (fs.existsSync(depsLockFilePath)) {
                return depsLockFilePath;
            }
        }
        return undefined;
    }
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        super(scope, id, {
            logRetention: aws_logs_1.RetentionDays.THREE_DAYS,
            architecture: aws_lambda_1.Architecture.ARM_64,
            memorySize: 768,
            timeout: aws_cdk_lib_1.Duration.seconds(30),
            runtime: aws_lambda_1.Runtime.NODEJS_20_X,
            depsLockFilePath: ExtendedNodejsFunction.findDepsLockFile(props.entry),
            ...props,
            environment: {
                NODE_OPTIONS: '--enable-source-maps',
                ...props.environment,
            },
            bundling: {
                sourceMap: (_b = (_a = props.bundling) === null || _a === void 0 ? void 0 : _a.sourceMap) !== null && _b !== void 0 ? _b : true,
                minify: true,
                ...props.bundling,
            },
        });
        this.alarms = new function_alarms_1.FunctionAlarms(this, 'Alarms', {
            function: this,
            logGroup: this.logGroup,
            ...props,
        });
        if ((_d = (_c = props.deploymentOptions) === null || _c === void 0 ? void 0 : _c.createDeployment) !== null && _d !== void 0 ? _d : true) {
            this.deployment = new function_deployment_1.FunctionDeployment(this, 'Deployment', {
                ...props.deploymentOptions,
                function: this,
            });
            if ((_f = (_e = props.deploymentOptions) === null || _e === void 0 ? void 0 : _e.includeCriticalAlarms) !== null && _f !== void 0 ? _f : true) {
                this.deployment.addAlarms(...this.alarms.getCriticalAlarms());
            }
            if ((_h = (_g = props.deploymentOptions) === null || _g === void 0 ? void 0 : _g.includeWarningAlarms) !== null && _h !== void 0 ? _h : false) {
                this.deployment.addAlarms(...this.alarms.getWarningAlarms());
            }
        }
    }
}
exports.ExtendedNodejsFunction = ExtendedNodejsFunction;
//# sourceMappingURL=extended-nodejs-function.js.map