"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FunctionAlarms = void 0;
const aws_monitoring_1 = require("../../aws-monitoring");
const aws_cloudwatch_1 = require("../../aws-cloudwatch");
/**
 * Creates CloudWatch alarms for a Lambda Function.
 */
class FunctionAlarms extends aws_monitoring_1.AlarmsBase {
    addFunctionMonitoring() {
        var _a, _b, _c;
        if (this.monitoringFacade === undefined) {
            throw new Error('monitoringFacade is undefined');
        }
        this.monitoringFacade.monitorLambdaFunction({
            alarmFriendlyName: this.props.alarmNamePrefix,
            lambdaFunction: this.props.function,
            addToAlarmDashboard: (_a = this.props.addToAlarmDashboard) !== null && _a !== void 0 ? _a : true,
            addToDetailDashboard: (_b = this.props.addToDetailDashboard) !== null && _b !== void 0 ? _b : true,
            addToSummaryDashboard: (_c = this.props.addToSummaryDashboard) !== null && _c !== void 0 ? _c : true,
            addLatencyP50Alarm: this.toRecord('p50Latency', 'maxLatency'),
            addLatencyP90Alarm: this.toRecord('p90Latency', 'maxLatency'),
            addLatencyP99Alarm: this.toRecord('p99Latency', 'maxLatency'),
            addFaultCountAlarm: this.toRecord('maxFaults', 'maxErrorCount', 0),
            addFaultRateAlarm: this.toRecord('avgFaults', 'maxErrorRate'),
            addLowTpsAlarm: this.toRecord('minTps', 'minTps'),
            addHighTpsAlarm: this.toRecord('maxTps', 'maxTps'),
            addThrottlesCountAlarm: this.toRecord('maxThrottles', 'maxErrorCount', 0),
            addThrottlesRateAlarm: this.toRecord('avgThrottles', 'maxErrorRate'),
            addConcurrentExecutionsCountAlarm: this.toRecord('maxConcurrentExecutions', 'maxRunningTasks'),
            addMaxIteratorAgeAlarm: this.toRecord('maxIteratorAge', 'maxAgeInMillis'),
            addEnhancedMonitoringMaxCpuTotalTimeAlarm: this.toRecord('maxCpuTime', 'maxDuration'),
            addEnhancedMonitoringP90CpuTotalTimeAlarm: this.toRecord('p90CpuTime', 'maxDuration'),
            addEnhancedMonitoringAvgCpuTotalTimeAlarm: this.toRecord('avgCpuTime', 'maxDuration'),
            addEnhancedMonitoringMaxMemoryUtilizationAlarm: this.toRecord('maxMemory', 'maxUsagePercent'),
            addEnhancedMonitoringP90MemoryUtilizationAlarm: this.toRecord('p90Memory', 'maxUsagePercent'),
            addEnhancedMonitoringAvgMemoryUtilizationAlarm: this.toRecord('avgMemory', 'maxUsagePercent'),
        });
    }
    addLogAlarm(category, defaultThreshold) {
        var _a, _b, _c, _d;
        const fprops = category === aws_monitoring_1.AlarmCategory.Critical
            ? this.props.criticalAlarmOptions
            : this.props.warningAlarmOptions;
        const threshold = (_a = fprops === null || fprops === void 0 ? void 0 : fprops.maxLogCount) !== null && _a !== void 0 ? _a : defaultThreshold;
        const pattern = ((_b = fprops === null || fprops === void 0 ? void 0 : fprops.metricLogPattern) !== null && _b !== void 0 ? _b : category === aws_monitoring_1.AlarmCategory.Critical)
            ? FunctionAlarms.DEFAULT_CRITICAL_LOG_METRIC_PATTERN
            : FunctionAlarms.DEFAULT_WARNING_LOG_METRIC_PATTERN;
        const evaluationPeriods = (_c = fprops === null || fprops === void 0 ? void 0 : fprops.logEvaluationPeriods) !== null && _c !== void 0 ? _c : 2;
        const datapointsToAlarm = (_d = fprops === null || fprops === void 0 ? void 0 : fprops.logDataPointsToAlarm) !== null && _d !== void 0 ? _d : 1;
        if (threshold !== undefined && threshold > 0) {
            const logAlarm = new aws_cloudwatch_1.LogMetricAlarm(this, category + 'LogCount', {
                logGroup: this.props.logGroup,
                pattern,
                threshold,
                evaluationPeriods,
                datapointsToAlarm,
                metricName: category + 'LogCount',
            });
            if (category === aws_monitoring_1.AlarmCategory.Critical) {
                this.criticalLogAlarm = logAlarm;
            }
            else {
                this.warningLogAlarm = logAlarm;
            }
        }
    }
    addLogMonitoringToDashboard() {
        var _a, _b, _c, _d;
        let pattern = FunctionAlarms.DEFAULT_LOG_INSIGHTS_PATTERN;
        if (((_a = this.props.criticalAlarmOptions) === null || _a === void 0 ? void 0 : _a.dashboardLogPattern) !== undefined ||
            ((_b = this.props.warningAlarmOptions) === null || _b === void 0 ? void 0 : _b.dashboardLogPattern) !== undefined) {
            pattern = '';
            if (((_c = this.props.criticalAlarmOptions) === null || _c === void 0 ? void 0 : _c.dashboardLogPattern) !== undefined) {
                pattern = this.props.criticalAlarmOptions.dashboardLogPattern;
            }
            if (((_d = this.props.warningAlarmOptions) === null || _d === void 0 ? void 0 : _d.dashboardLogPattern) !== undefined) {
                pattern =
                    pattern +
                        (pattern !== '' ? '|' : '') +
                        this.props.warningAlarmOptions.dashboardLogPattern;
            }
        }
        if (pattern !== '') {
            if (this.monitoringFacade === undefined) {
                throw new Error('monitoringFacade is undefined');
            }
            this.monitoringFacade.monitorLog({
                alarmFriendlyName: 'Monitor{this.props.logGroup.logGroupName}',
                logGroupName: this.props.logGroup.logGroupName,
                pattern,
            });
        }
    }
    constructor(scope, id, props) {
        var _a;
        super(scope, id, props);
        if ((_a = props.createAlarms) !== null && _a !== void 0 ? _a : true) {
            this.addFunctionMonitoring();
            this.addLogMonitoringToDashboard();
            this.addLogAlarm(aws_monitoring_1.AlarmCategory.Critical, 1);
            this.addLogAlarm(aws_monitoring_1.AlarmCategory.Warning);
        }
    }
    getAlarms(category) {
        var _a, _b;
        const alarms = super.getAlarms(category);
        const logAlarm = category === aws_monitoring_1.AlarmCategory.Critical
            ? (_a = this.criticalLogAlarm) === null || _a === void 0 ? void 0 : _a.alarm
            : (_b = this.warningLogAlarm) === null || _b === void 0 ? void 0 : _b.alarm;
        if (logAlarm !== undefined) {
            alarms.push(logAlarm);
        }
        return alarms;
    }
}
exports.FunctionAlarms = FunctionAlarms;
/**
 * Default pattern used for the critical log metric.
 */
FunctionAlarms.DEFAULT_CRITICAL_LOG_METRIC_PATTERN = 'ERROR';
FunctionAlarms.BRACKET_ERROR_LOG_METRIC_PATTERN = '"[ERROR]"';
/**
 * Default pattern used for the warning log metric.
 */
FunctionAlarms.DEFAULT_WARNING_LOG_METRIC_PATTERN = 'WARNING';
FunctionAlarms.BRACKET_WARNING_LOG_METRIC_PATTERN = '"[WARNING]"';
/**
 * Default pattern used to show logs on the CloudWatch dashboard.
 */
FunctionAlarms.DEFAULT_LOG_INSIGHTS_PATTERN = 'ERROR|WARNING';
FunctionAlarms.BRACKET_LOG_INSIGHTS_PATTERN = '\\[ERROR\\]|\\[WARNING\\]';
//# sourceMappingURL=function-alarms.js.map