"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FunctionDeployment = void 0;
const aws_codedeploy_1 = require("aws-cdk-lib/aws-codedeploy");
const constructs_1 = require("constructs");
const aws_lambda_1 = require("aws-cdk-lib/aws-lambda");
/**
 * Creates an Alias and LambdaDeploymentGroup with reasonable defaults.
 */
class FunctionDeployment extends constructs_1.Construct {
    constructor(scope, id, props) {
        var _a, _b;
        super(scope, id);
        this.alias = new aws_lambda_1.Alias(this, 'Alias', {
            aliasName: (_a = props.aliasName) !== null && _a !== void 0 ? _a : 'deploy',
            version: props.function.currentVersion,
        });
        this.deploymentGroup = new aws_codedeploy_1.LambdaDeploymentGroup(this, 'Group', {
            ...props,
            alias: this.alias,
            deploymentConfig: (_b = props.deploymentConfig) !== null && _b !== void 0 ? _b : aws_codedeploy_1.LambdaDeploymentConfig.CANARY_10PERCENT_5MINUTES,
        });
    }
    /**
     * Associates an additional alarm with this Deployment Group.
     *
     * @param alarm the alarm to associate
     */
    addAlarm(alarm) {
        this.deploymentGroup.addAlarm(alarm);
    }
    /**
     * Associates additional alarms with this Deployment Group.
     *
     * @param alarms the alarms to associate
     */
    addAlarms(...alarms) {
        alarms.forEach(alarm => this.deploymentGroup.addAlarm(alarm));
    }
    /**
     * Associate a function to run before deployment begins.
     *
     * @param preHook the function to associate
     */
    addPreHook(preHook) {
        this.deploymentGroup.addPreHook(preHook);
    }
    /**
     * Associate a function to run after deployment completes.
     *
     * @param postHook the function to associate
     */
    addPostHook(postHook) {
        this.deploymentGroup.addPostHook(postHook);
    }
    /**
     * Grant a principal permission to codedeploy:PutLifecycleEventHookExecutionStatus on this deployment group resource.
     *
     * @param grantee resource to grant permission to
     */
    grantPutLifecycleEventHookExecutionStatus(grantee) {
        return this.deploymentGroup.grantPutLifecycleEventHookExecutionStatus(grantee);
    }
}
exports.FunctionDeployment = FunctionDeployment;
//# sourceMappingURL=function-deployment.js.map