import { FunctionOptions, Runtime } from 'aws-cdk-lib/aws-lambda';
import { Construct } from 'constructs';
import { StandardFunction, StandardFunctionOptions } from './standard-function';
import { DeployedFunctionOptions } from './extended-function';
import { FunctionAlarmsOptions } from './function-alarms';
/**
 * Properties for BundledPythonFunction.
 */
export interface BundledPythonFunctionProps extends FunctionOptions, FunctionAlarmsOptions, DeployedFunctionOptions, StandardFunctionOptions {
    /**
     * The path (relative to entry) to the index file containing the exported handler.
     *
     * @default 'index.py'
     */
    readonly index?: string;
    /**
     * The name of the exported handler in the index file.
     *
     * @default 'handler'
     */
    readonly handler?: string;
    /**
     * The runtime environment. Only runtimes of the Python family are supported.
     *
     * @default Runtime.PYTHON_3_9
     */
    readonly runtime?: Runtime;
}
/**
 * Python based Lambda Function
 */
export declare class StandardPythonFunction extends StandardFunction {
    static isLocalBundlingSupported(): boolean;
    /**
     * Creates a new Lambda Function
     */
    constructor(scope: Construct, id: string, props: BundledPythonFunctionProps);
}
