"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardPythonFunction = void 0;
const aws_lambda_1 = require("aws-cdk-lib/aws-lambda");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const helpers_1 = require("../../helpers");
const standard_function_1 = require("./standard-function");
const path = require("path");
const fs = require("fs");
/**
 * Python based Lambda Function
 */
class StandardPythonFunction extends standard_function_1.StandardFunction {
    static isLocalBundlingSupported() {
        return helpers_1.ShellHelper.pythonVersion() !== null;
    }
    /**
     * Creates a new Lambda Function
     */
    constructor(scope, id, props) {
        var _a, _b, _c;
        const runtime = (_a = props.runtime) !== null && _a !== void 0 ? _a : aws_lambda_1.Runtime.PYTHON_3_9;
        if (runtime.family !== aws_lambda_1.RuntimeFamily.PYTHON) {
            throw new Error('Runtime must be a Python runtime');
        }
        const handler = ((_b = props.index) !== null && _b !== void 0 ? _b : 'index.py').replace('.py', '') +
            '.' +
            ((_c = props.handler) !== null && _c !== void 0 ? _c : 'handler');
        const defaultBundlingScript = fs.readFileSync(path.join(path.dirname(fs.realpathSync(__filename)), 'bundle-python.sh'), 'utf-8');
        super(scope, id, {
            // defaults which may be overridden by ...props
            tracing: aws_lambda_1.Tracing.PASS_THROUGH,
            logRetention: aws_logs_1.RetentionDays.THREE_DAYS,
            architecture: aws_lambda_1.Architecture.ARM_64,
            memorySize: 768,
            timeout: aws_cdk_lib_1.Duration.seconds(30),
            ...props,
            bundlingEnvironment: {
                PIP_PROGRESS_BAR: 'off',
                PIP_DISABLE_PIP_VERSION_CHECK: '1',
                ...props.bundlingEnvironment,
            },
            runtime,
            handler,
            defaultBundlingScript,
            defaultBundlingImage: runtime.bundlingImage,
            isLocalBundlingSupported: StandardPythonFunction.isLocalBundlingSupported,
        });
    }
}
exports.StandardPythonFunction = StandardPythonFunction;
//# sourceMappingURL=standard-python-function.js.map