"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AlarmHelper = void 0;
const aws_cloudwatch_actions_1 = require("aws-cdk-lib/aws-cloudwatch-actions");
const alarm_facade_1 = require("./alarm-facade");
class AlarmHelper {
    /**
     * Helper function to combine an array if IAlarmAction and ITopic objects into a single IAlarmAction array.
     *
     * @param actions the actions
     * @param topics the topics
     */
    static combineActions(actions, topics) {
        const combined = [];
        actions === null || actions === void 0 ? void 0 : actions.forEach(action => combined.push(action));
        topics === null || topics === void 0 ? void 0 : topics.forEach(topic => combined.push(new aws_cloudwatch_actions_1.SnsAction(topic)));
        return combined;
    }
    /**
     * Helper function to generate categorized alarms.
     *
     * @param options the AlarmsOptions instance
     * @param oprop property from the AlarmsCategoryOptions instance
     * @param tprop property from the CustomAlarmThreshold instance
     * @param defaultCriticalThreshold optional default value for the critical threshold
     * @param defaultWarningThreshold optional default value for the warning threshold
     */
    static toRecord(options, oprop, tprop, defaultCriticalThreshold, defaultWarningThreshold) {
        return new alarm_facade_1.AlarmFacadeSet(options)
            .addAlarms(oprop, tprop, defaultCriticalThreshold, defaultWarningThreshold)
            .toRecord();
    }
}
exports.AlarmHelper = AlarmHelper;
//# sourceMappingURL=alarm-helper.js.map