"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AlarmsBase = exports.AlarmCategory = void 0;
const constructs_1 = require("constructs");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const alarm_helper_1 = require("./alarm-helper");
var AlarmCategory;
(function (AlarmCategory) {
    AlarmCategory["Critical"] = "Critical";
    AlarmCategory["Warning"] = "Warning";
})(AlarmCategory || (exports.AlarmCategory = AlarmCategory = {}));
/**
 * Base class for all Alarms constructs.
 */
class AlarmsBase extends constructs_1.Construct {
    /**
     * Helper method to generate alarm records.
     *
     * @param oprop property from the AlarmsCategoryOptions instance
     * @param tprop property from the CustomAlarmThreshold instance
     * @param defaultCriticalThreshold optional default value for the critical threshold
     * @param defaultWarningThreshold optional default value for the warning threshold
     * @protected
     */
    toRecord(oprop, tprop, defaultCriticalThreshold, defaultWarningThreshold) {
        return alarm_helper_1.AlarmHelper.toRecord(this.props, oprop, tprop, defaultCriticalThreshold, defaultWarningThreshold);
    }
    constructor(scope, id, props) {
        super(scope, id);
        this.props = props;
        if (props.monitoringFacade !== undefined) {
            this.monitoringFacade = props.monitoringFacade;
        }
        else {
            const stack = aws_cdk_lib_1.Stack.of(this);
            if ('monitoringFacade' in stack) {
                const mf = stack.monitoringFacade;
                if (mf !== undefined) {
                    this.monitoringFacade = mf;
                }
            }
        }
        if (this.monitoringFacade === undefined) {
            throw new Error('MonitoringFacade must be provided as a constructor property or as monitoringFacade property on parent Stack');
        }
    }
    getAlarms(category) {
        if (this.monitoringFacade === undefined) {
            throw new Error('MonitoringFacade must be provided as a constructor property or as monitoringFacade property on parent Stack');
        }
        return [
            ...this.monitoringFacade
                .createdAlarmsWithDisambiguator(category)
                .map(awa => awa.alarm)
                .values(),
        ];
    }
    getCriticalAlarms() {
        return this.getAlarms(AlarmCategory.Critical);
    }
    getWarningAlarms() {
        return this.getAlarms(AlarmCategory.Warning);
    }
}
exports.AlarmsBase = AlarmsBase;
//# sourceMappingURL=alarms-base.js.map