import { Construct } from 'constructs';
import { Certificate } from 'aws-cdk-lib/aws-certificatemanager';
import { Distribution } from 'aws-cdk-lib/aws-cloudfront';
import { ARecord } from 'aws-cdk-lib/aws-route53';
import { ExtendedConstruct, ExtendedConstructProps } from '../../aws-cdk';
import { DomainName } from '../../aws-route53';
export declare enum RedirectType {
    Permanent = 301,
    Temporary = 302
}
/**
 * Properties for DomainRedirect.
 */
export interface DomainRedirectProps extends ExtendedConstructProps {
    /**
     * The type of redirect to perform. Defaults to Permanent.
     *
     * @default Permanent
     */
    readonly type?: RedirectType;
    /**
     * The domain names to redirect.
     */
    readonly domainNames: DomainName[];
    /**
     * The target to redirect to. Ex. https://www.example.com
     */
    readonly target: string;
    /**
     * Comment to leave on the CloudFront distribution.
     */
    readonly comment?: string;
    /**
     * Appends the request URI to the target. Default is false.
     */
    readonly appendUri?: boolean;
}
/**
 * Creates a CloudFront distribution that redirects an entire domain to a target.
 */
export declare class DomainRedirect extends ExtendedConstruct {
    readonly certificate: Certificate;
    readonly distribution: Distribution;
    readonly records: ARecord[];
    constructor(scope: Construct, id: string, props: DomainRedirectProps);
}
