"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Website = exports.SourceType = void 0;
const aws_s3_1 = require("aws-cdk-lib/aws-s3");
const aws_cloudfront_1 = require("aws-cdk-lib/aws-cloudfront");
const aws_cloudfront_origins_1 = require("aws-cdk-lib/aws-cloudfront-origins");
const aws_certificatemanager_1 = require("aws-cdk-lib/aws-certificatemanager");
const aws_route53_1 = require("aws-cdk-lib/aws-route53");
const aws_route53_targets_1 = require("aws-cdk-lib/aws-route53-targets");
const aws_s3_deployment_1 = require("aws-cdk-lib/aws-s3-deployment");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_route53_2 = require("../../aws-route53");
const aws_cdk_1 = require("../../aws-cdk");
const truemark_1 = require("../../truemark");
var SourceType;
(function (SourceType) {
    SourceType["Custom"] = "Custom";
    SourceType["Hugo"] = "Hugo";
    SourceType["NpmDist"] = "NpmDist";
    SourceType["Static"] = "Static";
})(SourceType || (exports.SourceType = SourceType = {}));
class Website extends aws_cdk_1.ExtendedConstruct {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        super(scope, id, {
            standardTags: aws_cdk_1.StandardTags.merge(props.standardTags, truemark_1.LibStandardTags),
        });
        const domainNames = aws_route53_2.DomainName.fromProps(props.domainNames);
        let certificate = undefined;
        if (props.certificateArn !== undefined) {
            certificate = aws_certificatemanager_1.Certificate.fromCertificateArn(this, 'Certificate', props.certificateArn);
        }
        else if (domainNames.length > 0) {
            certificate = new aws_certificatemanager_1.Certificate(this, 'Certificate', {
                domainName: domainNames[0].toString(),
                subjectAlternativeNames: aws_route53_2.DomainName.toStrings(domainNames).slice(1),
                validation: aws_certificatemanager_1.CertificateValidation.fromDnsMultiZone(aws_route53_2.DomainName.toZoneMap(this, domainNames)),
            });
        }
        this.bucket =
            (_a = props.bucket) !== null && _a !== void 0 ? _a : new aws_s3_1.Bucket(this, 'Bucket', {
                encryption: aws_s3_1.BucketEncryption.S3_MANAGED,
                removalPolicy: aws_cdk_lib_1.RemovalPolicy.DESTROY,
                autoDeleteObjects: true,
            });
        this.fallbackBucket = props.fallbackBucket;
        this.originAccessIdentity = new aws_cloudfront_1.OriginAccessIdentity(this, 'Access');
        this.bucket.grantRead(this.originAccessIdentity);
        if (this.fallbackBucket) {
            this.fallbackBucket.grantRead(this.originAccessIdentity);
        }
        this.apexDomain = domainNames.length > 0 ? domainNames[0].toString() : '';
        this.viewerRequestFunction = new aws_cloudfront_1.Function(this, 'ViewerRequestFunction', {
            code: aws_cloudfront_1.FunctionCode.fromInline(`
function handler(event) {
  var host = event.request.headers.host.value;
  var uri = event.request.uri;
  var matchApex = MATCH_APEX;
  if (matchApex && host !== "APEX_DOMAIN") {
    return {
      statusCode: 301,
      statusDescription: "Permanently moved",
      headers: {
        "location": { "value": "https://APEX_DOMAIN" + uri }
      }
    }
  }
  if (uri.endsWith("/")) {
    event.request.uri = uri + "index.html";
  }
  return event.request;
}`
                .replace(/APEX_DOMAIN/g, this.apexDomain)
                .replace(/MATCH_APEX/g, this.apexDomain !== '' && ((_b = props.redirectToApexDomain) !== null && _b !== void 0 ? _b : true)
                ? 'true'
                : 'false')),
        });
        const bucketOrigin = new aws_cloudfront_origins_1.S3Origin(this.bucket, {
            originAccessIdentity: this.originAccessIdentity,
        });
        const fallbackBucketOrigin = this.fallbackBucket === undefined
            ? undefined
            : new aws_cloudfront_origins_1.S3Origin(this.fallbackBucket, {
                originAccessIdentity: this.originAccessIdentity,
            });
        const defaultOrigin = fallbackBucketOrigin === undefined
            ? bucketOrigin
            : new aws_cloudfront_origins_1.OriginGroup({
                primaryOrigin: bucketOrigin,
                fallbackOrigin: fallbackBucketOrigin,
            });
        this.distribution = new aws_cloudfront_1.Distribution(this, 'Distribution', {
            defaultBehavior: {
                origin: defaultOrigin,
                viewerProtocolPolicy: aws_cloudfront_1.ViewerProtocolPolicy.REDIRECT_TO_HTTPS,
                functionAssociations: [
                    {
                        function: this.viewerRequestFunction,
                        eventType: aws_cloudfront_1.FunctionEventType.VIEWER_REQUEST,
                    },
                ],
            },
            errorResponses: [
                {
                    httpStatus: 404,
                    responseHttpStatus: 404,
                    responsePagePath: '/404.html',
                },
            ],
            httpVersion: (_c = props.httpVersion) !== null && _c !== void 0 ? _c : aws_cloudfront_1.HttpVersion.HTTP1_1,
            minimumProtocolVersion: (_d = props.minimumProtocolVersion) !== null && _d !== void 0 ? _d : aws_cloudfront_1.SecurityPolicyProtocol.TLS_V1_2_2021,
            defaultRootObject: 'index.html',
            certificate,
            domainNames: aws_route53_2.DomainName.toStrings(domainNames),
            enableIpv6: true,
            priceClass: (_e = props.priceClass) !== null && _e !== void 0 ? _e : aws_cloudfront_1.PriceClass.PRICE_CLASS_100,
        });
        this.distributionUrl = `https://${this.apexDomain !== ''
            ? this.apexDomain
            : this.distribution.distributionDomainName}`;
        this.aRecords = [];
        for (const domainNameProps of (_f = props.domainNames) !== null && _f !== void 0 ? _f : []) {
            if ((_g = domainNameProps.createRecord) !== null && _g !== void 0 ? _g : true) {
                const domainName = aws_route53_2.DomainName.findDomainName(domainNameProps, domainNames);
                if (domainName !== undefined) {
                    this.aRecords.push(domainName.createARecord(this, aws_route53_1.RecordTarget.fromAlias(new aws_route53_targets_1.CloudFrontTarget(this.distribution))));
                }
            }
        }
        let bundlingOptions = undefined;
        if (props.sourceType === SourceType.Custom) {
            if (!props.sourceBundlingOptions) {
                throw new Error('sourceBundlingOptions is required if source type is Custom');
            }
            bundlingOptions = props.sourceBundlingOptions;
        }
        if (props.sourceType === SourceType.Static) {
            if (props.sourceBundlingOptions) {
                throw new Error('Cannot use sourceBundlingOptions with source type Static');
            }
        }
        if (props.sourceType === SourceType.Hugo) {
            bundlingOptions = Website.HUGO_BUNDLING_OPTIONS;
            if (props.sourceBundlingOptions) {
                throw new Error('Cannot use sourceBundlingOptions with source type Hugo');
            }
        }
        else if (props.sourceType === SourceType.NpmDist) {
            bundlingOptions = Website.NPM_DIST_BUNDLING_OPTIONS;
            if (props.sourceBundlingOptions) {
                throw new Error('Cannot use sourceBundlingOptions with source type NpmDist');
            }
        }
        const source = aws_s3_deployment_1.Source.asset(props.sourceDirectory, {
            bundling: bundlingOptions,
        });
        this.deployment = new aws_s3_deployment_1.BucketDeployment(this, 'Assets', {
            sources: [source],
            destinationBucket: this.bucket,
            distribution: this.distribution,
            cacheControl: [aws_s3_deployment_1.CacheControl.maxAge((_h = props.maxAge) !== null && _h !== void 0 ? _h : aws_cdk_lib_1.Duration.minutes(60))],
            prune: false,
        });
        if (this.fallbackBucket) {
            this.fallbackDeployment = new aws_s3_deployment_1.BucketDeployment(this, 'FallbackAssets', {
                sources: [source],
                destinationBucket: this.fallbackBucket,
                cacheControl: [
                    aws_s3_deployment_1.CacheControl.maxAge((_j = props.maxAge) !== null && _j !== void 0 ? _j : aws_cdk_lib_1.Duration.minutes(60)),
                ],
                prune: false,
            });
        }
    }
}
exports.Website = Website;
/**
 * The default bundling options for SourceType.Hugo.
 */
Website.HUGO_BUNDLING_OPTIONS = {
    image: aws_cdk_lib_1.DockerImage.fromRegistry('public.ecr.aws/truemark/hugo:latest'),
    command: ['-d', '/asset-output'],
};
/**
 * The default bundling options for SourceType.NpmDist. It"s expected that "npm run dist" command
 * will place files in ${CDK_BUNDLING_OUTPUT_DIR}. Example: "ng build --output-path=/asset-output"
 */
Website.NPM_DIST_BUNDLING_OPTIONS = {
    image: aws_cdk_lib_1.DockerImage.fromRegistry('node:16-alpine'),
    command: [
        // TODO Figure out how to cache .npmcache
        'sh',
        '-c',
        [
            'mkdir -p .npmcache',
            'npm ci --cache .npmcache --prefer-offline',
            'npm run dist',
        ].join(' && '),
    ],
};
//# sourceMappingURL=website.js.map