import { Construct } from 'constructs';
import { Distribution, HttpVersion, IOrigin, PriceClass, SecurityPolicyProtocol } from 'aws-cdk-lib/aws-cloudfront';
import { Duration } from 'aws-cdk-lib';
import { ICertificate } from 'aws-cdk-lib/aws-certificatemanager';
import { ARecord, IHostedZone } from 'aws-cdk-lib/aws-route53';
/**
 * Domain name properties.
 */
export interface WordPressDomainNameProps {
    /**
     * Domain name
     */
    readonly domainName: string;
    /**
     * Zone for the domain name.
     */
    readonly hostedZone?: string | IHostedZone;
}
/**
 * Properties for WordPressDistribution.
 */
export interface WordPressDistributionProps {
    /**
     * Origin to send requests to.
     */
    readonly origin: IOrigin;
    /**
     * Domain names mapped to this distribution.
     */
    readonly domainNames: WordPressDomainNameProps[];
    /**
     * The certificate to use on the distribution.
     * If one is not provided, one is created using the domainNames provided.
     */
    readonly certificate?: ICertificate;
    /**
     * Create DNS records for the distribution.
     *
     * @default - true
     */
    readonly createDnsRecords?: boolean;
    /**
     * HTTP versions to allow
     *
     * @default - HttpVersion.HTTP2_AND_3
     */
    readonly httpVersion?: HttpVersion;
    /**
     * Security protocol to enforce.
     *
     * @default - SecurityPolicyProtocol.TLS_V1_2_2021
     */
    readonly minimumProtocolVersion?: SecurityPolicyProtocol;
    /**
     * Enables IPv6
     *
     * @default - true
     */
    readonly enableIpv6?: boolean;
    /**
     * Price class to use.
     *
     * @default - PriceClass.PRICE_CLASS_ALL
     */
    readonly priceClass?: PriceClass;
    /**
     * Max TTL to apply to the default behavior.
     *
     * @default - Duration.days(1)
     */
    readonly defaultMaxTtl?: Duration;
    /**
     * Max TTL to apply to the static behaviors.
     *
     * @default - Duration.days(1)
     */
    readonly staticMaxTtl?: Duration;
    /**
     * Max TTL to apply to the dynamic behaviors.
     *
     * @default - Duration.seconds(0)
     */
    readonly dynamicMaxTtl?: Duration;
}
/**
 * Creates a new CloudFront distribution for WordPress.
 */
export declare class WordPressDistribution extends Construct {
    readonly distribution: Distribution;
    readonly dnsRecords: ARecord[];
    constructor(scope: Construct, id: string, props: WordPressDistributionProps);
}
