"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WordPressDistribution = void 0;
const constructs_1 = require("constructs");
const aws_cloudfront_1 = require("aws-cdk-lib/aws-cloudfront");
const aws_route53_1 = require("aws-cdk-lib/aws-route53");
const aws_route53_targets_1 = require("aws-cdk-lib/aws-route53-targets");
const aws_route53_2 = require("../../aws-route53");
const aws_cloudfront_2 = require("../../aws-cloudfront");
/**
 * Creates a new CloudFront distribution for WordPress.
 */
class WordPressDistribution extends constructs_1.Construct {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e;
        super(scope, id);
        const hostedDomainNames = [];
        props.domainNames.forEach(name => {
            if (name.hostedZone !== undefined) {
                hostedDomainNames.push(aws_route53_2.DomainName.fromFqdn(name.domainName, name.hostedZone));
            }
        });
        let certificate = props.certificate;
        if (certificate === undefined) {
            certificate = aws_route53_2.DomainName.createCertificate(this, 'Certificate', hostedDomainNames);
        }
        const originRequestPolicy = new aws_cloudfront_1.OriginRequestPolicy(this, 'AllViewerPlus', {
            cookieBehavior: aws_cloudfront_1.OriginRequestCookieBehavior.all(),
            headerBehavior: aws_cloudfront_1.OriginRequestHeaderBehavior.all('CloudFront-Forwarded-Proto'),
            queryStringBehavior: aws_cloudfront_1.OriginRequestQueryStringBehavior.all(),
        });
        const builder = new aws_cloudfront_2.DistributionBuilder(this, 'Default')
            .httpVersion((_a = props.httpVersion) !== null && _a !== void 0 ? _a : aws_cloudfront_1.HttpVersion.HTTP2_AND_3)
            .minimumProtocolVersion((_b = props.minimumProtocolVersion) !== null && _b !== void 0 ? _b : aws_cloudfront_1.SecurityPolicyProtocol.TLS_V1_2_2021)
            .enableIpv6((_c = props.enableIpv6) !== null && _c !== void 0 ? _c : true)
            .priceClass((_d = props.priceClass) !== null && _d !== void 0 ? _d : aws_cloudfront_1.PriceClass.PRICE_CLASS_ALL)
            .domainNames(...props.domainNames.map(domainName => domainName.domainName))
            .certificate(certificate)
            .behavior(props.origin)
            .viewerProtocolPolicy(aws_cloudfront_1.ViewerProtocolPolicy.REDIRECT_TO_HTTPS)
            .compress(true)
            .allowedMethods(aws_cloudfront_1.AllowedMethods.ALLOW_ALL)
            .originRequestPolicy(originRequestPolicy)
            .cachePolicy(aws_cloudfront_1.CachePolicy.CACHING_DISABLED)
            .behavior(props.origin, '/wp-includes/*')
            .viewerProtocolPolicy(aws_cloudfront_1.ViewerProtocolPolicy.REDIRECT_TO_HTTPS)
            .compress(true)
            .allowedMethods(aws_cloudfront_1.AllowedMethods.ALLOW_GET_HEAD_OPTIONS)
            .originRequestPolicy(originRequestPolicy)
            .cachePolicy(aws_cloudfront_1.CachePolicy.CACHING_DISABLED)
            .behavior(props.origin, '/wp-content/*')
            .viewerProtocolPolicy(aws_cloudfront_1.ViewerProtocolPolicy.REDIRECT_TO_HTTPS)
            .compress(true)
            .allowedMethods(aws_cloudfront_1.AllowedMethods.ALLOW_GET_HEAD_OPTIONS)
            .originRequestPolicy(originRequestPolicy)
            .cachePolicy(aws_cloudfront_1.CachePolicy.CACHING_DISABLED)
            .behavior(props.origin, '/wp-login.php')
            .viewerProtocolPolicy(aws_cloudfront_1.ViewerProtocolPolicy.REDIRECT_TO_HTTPS)
            .compress(true)
            .allowedMethods(aws_cloudfront_1.AllowedMethods.ALLOW_ALL)
            .originRequestPolicy(originRequestPolicy)
            .cachePolicy(aws_cloudfront_1.CachePolicy.CACHING_DISABLED)
            .behavior(props.origin, '/wp-admin/*')
            .viewerProtocolPolicy(aws_cloudfront_1.ViewerProtocolPolicy.REDIRECT_TO_HTTPS)
            .compress(true)
            .allowedMethods(aws_cloudfront_1.AllowedMethods.ALLOW_ALL)
            .originRequestPolicy(originRequestPolicy)
            .cachePolicy(aws_cloudfront_1.CachePolicy.CACHING_DISABLED);
        const distribution = new aws_cloudfront_1.Distribution(this, 'Default', builder.build());
        const dnsRecords = [];
        if ((_e = props.createDnsRecords) !== null && _e !== void 0 ? _e : true) {
            const recordTarget = aws_route53_1.RecordTarget.fromAlias(new aws_route53_targets_1.CloudFrontTarget(distribution));
            hostedDomainNames.forEach(name => {
                dnsRecords.push(name.createARecord(this, recordTarget));
            });
        }
        this.distribution = distribution;
        this.dnsRecords = dnsRecords;
    }
}
exports.WordPressDistribution = WordPressDistribution;
//# sourceMappingURL=word-press-distribution.js.map