"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtendedRecordTarget = void 0;
const aws_route53_1 = require("aws-cdk-lib/aws-route53");
class AliasRecordTargetWrapper {
    constructor(target, evaluateTargetHealth) {
        this.target = target;
        this.evaluateTargetHealth = evaluateTargetHealth;
    }
    bind(record, zone) {
        return {
            ...this.target.bind(record, zone),
            evaluateTargetHealth: this.evaluateTargetHealth,
        };
    }
}
/**
 * Extends the RecordTarget class providing the ability to set evaluateTargetHealth for alias records.
 */
class ExtendedRecordTarget extends aws_route53_1.RecordTarget {
    constructor(values, aliasTarget, evaluateTargetHealth) {
        super(values, aliasTarget
            ? new AliasRecordTargetWrapper(aliasTarget, evaluateTargetHealth)
            : undefined);
    }
    /**
     * Creates a new RecordTarget from an alias.
     *
     * @param aliasTarget the alias to target
     * @param evaluateTargetHealth determines if Route53 should evaluate target health
     */
    static fromAlias(aliasTarget, evaluateTargetHealth) {
        return new ExtendedRecordTarget(undefined, aliasTarget, evaluateTargetHealth);
    }
}
exports.ExtendedRecordTarget = ExtendedRecordTarget;
//# sourceMappingURL=extended-record-target.js.map