"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReplicationRole = void 0;
const constructs_1 = require("constructs");
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
const aws_cdk_lib_1 = require("aws-cdk-lib");
class ReplicationRole extends constructs_1.Construct {
    constructor(scope, id, props) {
        super(scope, id);
        const stack = aws_cdk_lib_1.Stack.of(this);
        const replicationRole = new aws_iam_1.Role(this, 'Default', {
            assumedBy: new aws_iam_1.ServicePrincipal('s3.amazonaws.com'),
        });
        replicationRole.addToPolicy(new aws_iam_1.PolicyStatement({
            actions: [
                's3:ListBucket',
                's3:GetReplicationConfiguration',
                's3:GetObjectVersionForReplication',
                's3:GetObjectVersionAcl',
                's3:GetObjectVersionTagging',
                's3:GetObjectRetention',
                's3:GetObjectLegalHold',
            ],
            resources: [
                `arn:aws:s3:::${props.sourceBucketName}`,
                `arn:aws:s3:::${props.sourceBucketName}/*`,
                ...props.destinationBuckets.map(dest => `arn:aws:s3:::${dest.bucketName}`),
                ...props.destinationBuckets.map(dest => `arn:aws:s3:::${dest.bucketName}/*`),
            ],
        }));
        replicationRole.addToPolicy(new aws_iam_1.PolicyStatement({
            actions: ['s3:Replicate*', 's3:ObjectOwnerOverrideToBucketOwner'],
            resources: [
                `arn:aws:s3:::${props.sourceBucketName}/*`,
                ...props.destinationBuckets.map(dest => `arn:aws:s3:::${dest.bucketName}/*`),
            ],
        }));
        replicationRole.addToPolicy(new aws_iam_1.PolicyStatement({
            actions: ['kms:Encrypt'],
            resources: props.destinationBuckets.map(dest => {
                var _a, _b;
                return `arn:aws:kms:${(_a = dest.region) !== null && _a !== void 0 ? _a : stack.region}:${(_b = dest.account) !== null && _b !== void 0 ? _b : stack.account}:key/*`;
            }),
        }));
        replicationRole.addToPolicy(new aws_iam_1.PolicyStatement({
            actions: ['kms:Decrypt'],
            resources: [`arn:aws:kms:${stack.region}:${stack.account}:key/*`],
        }));
        this.role = replicationRole;
        this.roleArn = replicationRole.roleArn;
        this.roleName = replicationRole.roleName;
        this.assumeRoleAction = replicationRole.assumeRoleAction;
        this.policyFragment = replicationRole.policyFragment;
        this.principalAccount = replicationRole.principalAccount;
        this.grantPrincipal = replicationRole.grantPrincipal;
        this.stack = replicationRole.stack;
        this.env = replicationRole.env;
    }
    grant(grantee, ...actions) {
        return this.role.grant(grantee, ...actions);
    }
    grantPassRole(grantee) {
        return this.role.grantPassRole(grantee);
    }
    grantAssumeRole(grantee) {
        return this.role.grantAssumeRole(grantee);
    }
    addToPrincipalPolicy(statement) {
        return this.role.addToPrincipalPolicy(statement);
    }
    attachInlinePolicy(policy) {
        return this.role.attachInlinePolicy(policy);
    }
    addManagedPolicy(policy) {
        return this.role.addManagedPolicy(policy);
    }
    applyRemovalPolicy(policy) {
        return this.role.applyRemovalPolicy(policy);
    }
}
exports.ReplicationRole = ReplicationRole;
//# sourceMappingURL=replication-role.js.map