"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueueAlarms = void 0;
const aws_monitoring_1 = require("../../aws-monitoring");
/**
 * Creates CloudWatch alarms for Queues.
 */
class QueueAlarms extends aws_monitoring_1.AlarmsBase {
    addQueueMonitoring() {
        if (this.monitoringFacade === undefined) {
            throw new Error('monitoringFacade is undefined');
        }
        if (this.props.queue.deadLetterQueue === undefined) {
            this.monitoringFacade.monitorSqsQueue({
                alarmFriendlyName: this.props.alarmFriendlyName,
                queue: this.props.queue,
                addQueueMinSizeAlarm: this.toRecord('minSize', 'minMessageCount'),
                addQueueMaxSizeAlarm: this.toRecord('maxSize', 'maxMessageCount'),
                addQueueMaxMessageAgeAlarm: this.toRecord('maxAgeInSeconds', 'maxAgeInSeconds', 15),
                addQueueMaxTimeToDrainMessagesAlarm: this.toRecord('maxTimeToDrain', 'maxTimeToDrain'),
                addQueueMinIncomingMessagesAlarm: this.toRecord('minIncoming', 'minIncomingMessagesCount'),
                addQueueMaxIncomingMessagesAlarm: this.toRecord('maxIncoming', 'maxIncomingMessagesCount'),
            });
        }
        else {
            this.monitoringFacade.monitorSqsQueueWithDlq({
                alarmFriendlyName: this.props.alarmFriendlyName,
                queue: this.props.queue,
                deadLetterQueue: this.props.queue.deadLetterQueue.queue,
                addQueueMinSizeAlarm: this.toRecord('minSize', 'minMessageCount'),
                addQueueMaxSizeAlarm: this.toRecord('maxSize', 'maxMessageCount'),
                addQueueMaxMessageAgeAlarm: this.toRecord('maxAgeInSeconds', 'maxAgeInSeconds', 15),
                addQueueMaxTimeToDrainMessagesAlarm: this.toRecord('maxTimeToDrain', 'maxTimeToDrain'),
                addQueueMinIncomingMessagesAlarm: this.toRecord('minIncoming', 'minIncomingMessagesCount'),
                addQueueMaxIncomingMessagesAlarm: this.toRecord('maxIncoming', 'maxIncomingMessagesCount'),
                addDeadLetterQueueMaxSizeAlarm: this.toRecord('deadLetterQueueMaxSize', 'maxMessageCount', 0),
                addDeadLetterQueueMaxMessageAgeAlarm: this.toRecord('deadLetterQueueMaxAgeInSeconds', 'maxAgeInSeconds'),
                addDeadLetterQueueMaxIncomingMessagesAlarm: this.toRecord('deadLetterQueueMaxIncoming', 'maxIncomingMessagesCount'),
                addDeadLetterQueueToSummaryDashboard: true,
            });
        }
    }
    constructor(scope, id, props) {
        var _a;
        super(scope, id, props);
        if ((_a = props.createAlarms) !== null && _a !== void 0 ? _a : true) {
            this.addQueueMonitoring();
        }
    }
}
exports.QueueAlarms = QueueAlarms;
//# sourceMappingURL=queue-alarms.js.map