"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParameterPaths = void 0;
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
const aws_cdk_lib_1 = require("aws-cdk-lib");
/**
 * Represents a group of SSM Parameter paths.
 */
class ParameterPaths {
    constructor(scope, ...paths) {
        this.stack = aws_cdk_lib_1.Stack.of(scope);
        paths.forEach(path => this.validatePath(path));
        this.paths = paths;
    }
    validatePath(path) {
        if (!path.startsWith('/')) {
            throw new Error("path must start with a '/'");
        }
    }
    grantDescribe(grantee) {
        return aws_iam_1.Grant.addToPrincipal({
            grantee,
            actions: ['ssm:DescribeParameters'],
            resourceArns: ['*'],
        });
    }
    grantRead(grantee) {
        return aws_iam_1.Grant.addToPrincipal({
            grantee,
            actions: [
                'ssm:GetParameter',
                'ssm:GetParameters',
                'ssm:GetParametersByPath',
                'ssm:GetParameterHistory',
            ],
            resourceArns: this.paths.map(path => `arn:aws:ssm:${this.stack.region}:${this.stack.account}:parameter${path}`),
        });
    }
    grantWrite(grantee) {
        return aws_iam_1.Grant.addToPrincipal({
            grantee,
            actions: [
                'ssm:PutParameter',
                'ssm:DeleteParameter',
                'ssm:DeleteParameters',
            ],
            resourceArns: this.paths.map(path => `arn:aws:ssm:${this.stack.region}:${this.stack.account}:parameter${path}`),
        });
    }
    grantReadWrite(grantee) {
        return aws_iam_1.Grant.addToPrincipal({
            grantee,
            actions: [
                'ssm:GetParameter',
                'ssm:GetParameters',
                'ssm:GetParametersByPath',
                'ssm:GetParameterHistory',
                'ssm:PutParameter',
                'ssm:DeleteParameter',
                'ssm:DeleteParameters',
            ],
            resourceArns: this.paths.map(path => `arn:aws:ssm:${this.stack.region}:${this.stack.account}:parameter${path}`),
        });
    }
}
exports.ParameterPaths = ParameterPaths;
//# sourceMappingURL=parameter-paths.js.map