"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParameterReader = void 0;
const custom_resources_1 = require("aws-cdk-lib/custom-resources");
const aws_iam_1 = require("aws-cdk-lib/aws-iam");
const aws_cdk_lib_1 = require("aws-cdk-lib");
/**
 * Custom resource allowing SSM parameter strings to be read across regions.
 */
class ParameterReader extends custom_resources_1.AwsCustomResource {
    constructor(scope, id, props) {
        var _a;
        const call = {
            service: 'SSM',
            action: 'getParameter',
            parameters: {
                Name: props.parameterName,
            },
            region: props.region,
            physicalResourceId: { id: Date.now().toString() },
        };
        super(scope, id, {
            installLatestAwsSdk: false,
            onUpdate: call,
            policy: {
                statements: [
                    new aws_iam_1.PolicyStatement({
                        resources: ['*'],
                        actions: ['ssm:GetParameter'],
                        effect: aws_iam_1.Effect.ALLOW,
                    }),
                ],
            },
            timeout: (_a = props.timeout) !== null && _a !== void 0 ? _a : aws_cdk_lib_1.Duration.minutes(2),
        });
    }
    getStringValue() {
        return this.getResponseField('Parameter.Value').toString();
    }
}
exports.ParameterReader = ParameterReader;
//# sourceMappingURL=parameter-reader.js.map