import { Construct } from 'constructs';
import { StringParameter } from 'aws-cdk-lib/aws-ssm';
/**
 * Properties for ParameterStore
 */
export interface ParameterStoreOptions {
    readonly prefix?: string;
    readonly suffix?: string;
    readonly region?: string;
}
/**
 * Utility construct to ease reading and writing parameters with cross-region read support.
 */
export declare class ParameterStore extends Construct {
    /**
     * The region in which to access the parameters.
     */
    readonly region: string;
    /**
     * The prefix on parameters read and written by this store.
     */
    readonly prefix: string;
    /**
     * The prefix used on identifiers.
     */
    readonly identifierPrefix: string;
    /**
     * The suffix on parameters read and written by this store.
     */
    readonly suffix: string;
    /**
     * The suffix used on identifiers.
     */
    readonly identifierSuffix: string;
    constructor(scope: Construct, id: string, props?: ParameterStoreOptions);
    regionMatch(): boolean;
    protected readLocal(name: string): string;
    protected readRemote(name: string): string;
    /**
     * Reads an SSM parameter from a local or remote region.
     *
     * @param name the name of the parameter to read
     */
    read(name: string): string;
    /**
     * Creates a new SSM parameter in the local region.
     *
     * @param name the name of the parameter
     * @param value the value to store
     */
    write(name: string, value: string): StringParameter;
}
