"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParameterStore = void 0;
const aws_cdk_lib_1 = require("aws-cdk-lib");
const constructs_1 = require("constructs");
const aws_ssm_1 = require("aws-cdk-lib/aws-ssm");
const parameter_reader_1 = require("./parameter-reader");
/**
 * Utility construct to ease reading and writing parameters with cross-region read support.
 */
class ParameterStore extends constructs_1.Construct {
    constructor(scope, id, props) {
        var _a, _b, _c;
        super(scope, id);
        this.prefix = (_a = props === null || props === void 0 ? void 0 : props.prefix) !== null && _a !== void 0 ? _a : '';
        this.identifierPrefix =
            this.prefix.replace(/\//, '-') + (this.prefix === '' ? '' : '-');
        this.suffix = (_b = props === null || props === void 0 ? void 0 : props.suffix) !== null && _b !== void 0 ? _b : '';
        this.identifierSuffix =
            (this.suffix === '' ? '' : '-') + this.suffix.replace(/\//, '-');
        this.region = (_c = props === null || props === void 0 ? void 0 : props.region) !== null && _c !== void 0 ? _c : aws_cdk_lib_1.Stack.of(this).region;
    }
    regionMatch() {
        return this.region === aws_cdk_lib_1.Stack.of(this).region;
    }
    readLocal(name) {
        return aws_ssm_1.StringParameter.valueForStringParameter(this, this.prefix + name + this.suffix);
    }
    readRemote(name) {
        return new parameter_reader_1.ParameterReader(this, this.identifierPrefix + name + this.identifierSuffix, {
            parameterName: this.prefix + name + this.suffix,
            region: this.region,
        }).getStringValue();
    }
    /**
     * Reads an SSM parameter from a local or remote region.
     *
     * @param name the name of the parameter to read
     */
    read(name) {
        return this.regionMatch() ? this.readLocal(name) : this.readRemote(name);
    }
    /**
     * Creates a new SSM parameter in the local region.
     *
     * @param name the name of the parameter
     * @param value the value to store
     */
    write(name, value) {
        if (!this.regionMatch()) {
            throw new Error('Cannot write to a different region');
        }
        return new aws_ssm_1.StringParameter(this, this.identifierPrefix + name + this.identifierSuffix, {
            parameterName: this.prefix + name + this.suffix,
            stringValue: value,
        });
    }
}
exports.ParameterStore = ParameterStore;
//# sourceMappingURL=parameter-store.js.map