import { Construct } from 'constructs';
import { StringListParameter, StringParameter } from 'aws-cdk-lib/aws-ssm';
import { ExtendedConstruct, ExtendedConstructProps } from '../../aws-cdk';
/**
 * Properties for NetworkParameters.
 */
export interface NetworkParametersProps extends ExtendedConstructProps {
    /**
     * Name of the network. This is normally the name of your VPC.
     */
    readonly name: string;
    /**
     * Prefix from which to store and retrieve parameters. Default is "/network".
     *
     * @default - "/network"
     */
    readonly prefix?: string;
    /**
     * Setting this to false will disable the creation of resources in this construct. Default is true.
     *
     * @default - true
     */
    readonly create?: boolean;
    /**
     * Setting this to true will suppress the creation of default tags on resources created by this
     * construct. Default is false.
     *
     * @default - false
     */
    readonly suppressTagging?: boolean;
    /**
     * VPC ID to store.
     */
    readonly vpcId?: string;
    /**
     * Availability-zone values to store.
     */
    readonly azs?: string[];
    /**
     * Public subnet IDs to store.
     */
    readonly publicSubnetIds?: string[];
    /**
     * Private subnet IDs to store.
     */
    readonly privateSubnetIds?: string[];
    /**
     * Intra subnet IDs to store.
     */
    readonly intraSubnetIds?: string[];
    /**
     * Redshift subnet IDs to store.
     */
    readonly redshiftSubnetIds?: string[];
    /**
     * Database subnet IDs to store.
     */
    readonly databaseSubnetIds?: string[];
    /**
     * Elasticache subnet IDs to store.
     */
    readonly elasticacheSubnetIds?: string[];
    /**
     * Outpost subnet IDs to store.
     */
    readonly outpostSubnetIds?: string[];
    /**
     * Public ALB ARNs to store.
     */
    readonly publicAlbArns?: string[];
    /**
     * Private ALB ARNs to store.
     */
    readonly privateAlbArns?: string[];
    /**
     * Certificate ARNs on public ALBs to store. Indexes should match publicAlbArns.
     */
    readonly publicAlbCertificateArns?: string[];
    /**
     * Certificate ARNs on private ALBs to store. Indexes should match privateAlbArns.
     */
    readonly privateAlbCertificateArns?: string[];
    /**
     * Alternative public ALB ARNs to store.
     */
    readonly altPublicAlbArns?: string[];
    /**
     * Alternative private ALB ARNs to store.
     */
    readonly altPrivateAlbArns?: string[];
    /**
     * Alternative certificate ARNs on public ALBs to store. Indexes should match publicAlbArns.
     */
    readonly altPublicAlbCertificateArns?: string[];
    /**
     * Alternative certificate ARNs on private ALBs to store. Indexes should match privateAlbArns.
     */
    readonly altPrivateAlbCertificateArns?: string[];
    /**
     * Public certificate ARN to store for this network.
     */
    readonly publicCertificateArn?: string;
    /**
     * Private certificate ARN to store for this network.
     */
    readonly privateCertificateArn?: string;
    /**
     * CloudFront certificate ARN to store for this network.
     */
    readonly cloudFontCertificateArn?: string;
    /**
     * Public zone name to store for this network.
     */
    readonly publicZoneName?: string;
    /**
     * Private zone name to store for this network.
     */
    readonly privateZoneName?: string;
    /**
     * Lookup VPC value if not provided. Default is true.
     *
     * @default - true
     */
    readonly lookupVpc?: boolean;
    /**
     * Lookup availability zones if not provided. Default is true.
     *
     * @default - true
     */
    readonly lookupAzs?: boolean;
    /**
     * Lookup public subnets if not provided. Default is true.
     *
     * @default - true
     */
    readonly lookupPublicSubnets?: boolean;
    /**
     * Lookup private subnets if not provided. Default is true.
     *
     * @default - true
     */
    readonly lookupPrivateSubnets?: boolean;
    /**
     * Lookup intra subnets if not provided. Default is false.
     *
     * @default - false
     */
    readonly lookupIntraSubnets?: boolean;
    /**
     * Lookup redshift subnets if not provided. Default is false.
     *
     * @default - false
     */
    readonly lookupRedshiftSubnets?: boolean;
    /**
     * Lookup database subnets if not provided. Default is false.
     *
     * @default - false
     */
    readonly lookupDatabaseSubnets?: boolean;
    /**
     * Lookup elasticache subnets if not provided. Default is false.
     *
     * @default - false
     */
    readonly lookupElasticacheSubnets?: boolean;
    /**
     * Lookup outpost subnets if not provided. Default is false.
     *
     * @default - false
     */
    readonly lookupOutpostSubnets?: boolean;
    /**
     * Lookup public ALBs if not provided. Default is false.
     *
     * @default - false
     */
    readonly lookupPublicAlbs?: boolean;
    /**
     * Lookup private ALBs if not provided. Default is false.
     *
     * @default - false
     */
    readonly lookupPrivateAlbs?: boolean;
    /**
     * Lookup ACM certificates on public ALBs if provided. Default is false.
     */
    readonly lookupPublicAlbCertificates?: boolean;
    /**
     * Lookup ACM certificates on private ALBs if provided. Default is false.
     */
    readonly lookupPrivateAlbCertificates?: boolean;
    /**
     * Lookup alternative public ALBs if not provided. Default is false.
     *
     * @default - false
     */
    readonly lookupAltPublicAlbs?: boolean;
    /**
     * Lookup alternative private ALBs if not provided. Default is false.
     *
     * @default - false
     */
    readonly lookupAltPrivateAlbs?: boolean;
    /**
     * Lookup alternative ACM certificates on public ALBs if provided. Default is false.
     *
     * @default - false
     */
    readonly lookupAltPublicAlbCertificates?: boolean;
    /**
     * Lookup alternative ACM certificates on private ALBs if provided. Default is false.
     *
     * @default - false
     */
    readonly lookupAltPrivateAlbCertificates?: boolean;
    /**
     * Lookup public certificate. Default is false.
     *
     * @default - false
     */
    readonly lookupPublicCertificate?: boolean;
    /**
     * Lookup private certificate. Default is false.
     *
     * @default - false
     */
    readonly lookupPrivateCertificate?: boolean;
    /**
     * Lookup CloudFront certificate. Default is false.
     *
     * @default - false
     */
    readonly lookupCloudFrontCertificate?: boolean;
    /**
     * Lookup public zone. Default is false.
     *
     * @default - false
     */
    readonly lookupPublicZone?: boolean;
    /**
     * Lookup private zone. Default is false.
     *
     * @default - false
     */
    readonly lookupPrivateZone?: boolean;
}
/**
 * Stores and retrieves network infrastructure identifiers using
 * AWS Systems Manager Parameter Store.
 */
export declare class NetworkParameters extends ExtendedConstruct {
    /**
     * Path to the VPC ID
     */
    readonly vpcParameterPath: string;
    /**
     * Path to the availability zones
     */
    readonly azsParameterPath: string;
    /**
     * Path to the public subnet IDs
     */
    readonly publicSubnetsParameterPath: string;
    /**
     * Path to the private subnet IDs
     */
    readonly privateSubnetsParameterPath: string;
    /**
     * Path to the intra subnet IDs
     */
    readonly intraSubnetsParameterPath: string;
    /**
     * Path to the redshift subnet IDs
     */
    readonly redshiftSubnetsParameterPath: string;
    /**
     * Path to the database subnet IDs
     */
    readonly databaseSubnetsParameterPath: string;
    /**
     * Path to the elasticache subnet IDs
     */
    readonly elasticacheSubnetsParameterPath: string;
    /**
     * Path to the outpost subnet IDs.
     */
    readonly outpostSubnetsParameterPath: string;
    /**
     * Path to the public ALB ARNs.
     */
    readonly publicAlbsParameterPath: string;
    /**
     * Path to the private ALB ARNs.
     */
    readonly privateAlbsParameterPath: string;
    /**
     * Path to the certificate ARNs on the public ALBs.
     */
    readonly publicAlbCertificatesParameterPath: string;
    /**
     * Path to the certificate ARNs on the private ALBs.
     */
    readonly privateAlbCertificatesParameterPath: string;
    /**
     * Path to the alternative public ALB ARNs.
     */
    readonly altPublicAlbsParameterPath: string;
    /**
     * Path to the alternative private ALB ARNs.
     */
    readonly altPrivateAlbsParameterPath: string;
    /**
     * Path to the alternative certificate ARNs on the public ALBs.
     */
    readonly altPublicAlbCertificatesParameterPath: string;
    /**
     * Path to the alternative certificate ARNs on the private ALBs.
     */
    readonly altPrivateAlbCertificatesParameterPath: string;
    /**
     * Path to the public certificate ARN.
     */
    readonly publicCertificateParameterPath: string;
    /**
     * Path to the private certificate ARN.
     */
    readonly privateCertificateParameterPath: string;
    /**
     * Path to the CloudFront certiticate ARN.
     */
    readonly cloudFrontCertificateParameterPath: string;
    /**
     * Path to the public zone.
     */
    readonly publicZoneParameterPath: string;
    /**
     * Path to the private zone.
     */
    readonly privateZoneParameterPath: string;
    /**
     * The parameter created if vpcId was provided.
     */
    readonly vpcParameter?: StringParameter;
    /**
     * The parameter created if azs were provided.
     */
    readonly azsParameter?: StringListParameter;
    /**
     * The parameter crated if publicSubnetIds were provided.
     */
    readonly publicSubnetsParameter?: StringListParameter;
    /**
     * The parameter created if privateSubnetIds were provided.
     */
    readonly privateSubnetsParameter?: StringListParameter;
    /**
     * The parameter created if intraSubnetIds were provided.
     */
    readonly intraSubnetsParameter?: StringListParameter;
    /**
     * The parameter created if redshiftSubnetIds were provided.
     */
    readonly redshiftSubnetsParameter?: StringListParameter;
    /**
     * The parameter created if databaseSubnetIds were provided.
     */
    readonly databaseSubnetsParameter?: StringListParameter;
    /**
     * The parameter created if elasticacheSubnetIds were provided.
     */
    readonly elasticacheSubnetsParameter?: StringListParameter;
    /**
     * The parameter created if outpostSubnetIds were provided.
     */
    readonly outpostSubnetsPrameter?: StringListParameter;
    /**
     * The parameter created if publicAlbArns were provided.
     */
    readonly publicAlbsParameter?: StringListParameter;
    /**
     * The parameter created if privateAlbArns were provided.
     */
    readonly privateAlbsParameter?: StringListParameter;
    /**
     * The parameter created if publicAlbCertificateArns were provided.
     */
    readonly publicAlbCertificatesParameter?: StringListParameter;
    /**
     * The parameter created if privateAlbCertificateArns were provided.
     */
    readonly privateAlbCertificatesParameter?: StringListParameter;
    /**
     * The parameter created if altPublicAlbArns were provided.
     */
    readonly altPublicAlbsParameter?: StringListParameter;
    /**
     * The parameter created if altPrivateAlbArns were provided.
     */
    readonly altPrivateAlbsParameter?: StringListParameter;
    /**
     * The parameter created if altPublicAlbCertificateArns were provided.
     */
    readonly altPublicAlbCertificatesParameter?: StringListParameter;
    /**
     * The parameter created if altPrivateAlbCertificateArns were provided.
     */
    readonly altPrivateAlbCertificatesParameter?: StringListParameter;
    /**
     * The parameter created if publicCertificateArn was provided.
     */
    readonly publicCertificateParameter?: StringParameter;
    /**
     * The parameter created if privateCertificateArn was provided.
     */
    readonly privateCertificateParameter?: StringParameter;
    /**
     * The parameter created if cloudFrontCertificateArn was provided.
     */
    readonly cloudFrontCertificateParameter?: StringParameter;
    /**
     * The parameter created if publicZoneName was provided.
     */
    readonly publicZoneParameter?: StringParameter;
    /**
     * The parameter created if privateZoneName was provided.
     */
    readonly privateZoneParameter?: StringParameter;
    /**
     * The vpcId if provided or lookups are enabled.
     */
    readonly vpcId?: string;
    /**
     * The availability zones if provided or lookups are enabled.
     */
    readonly azs?: string[];
    /**
     * The public subnet IDs if provided or lookups are enabled.
     */
    readonly publicSubnetIds?: string[];
    /**
     * The private subnet IDs if provided or lookups are enabled.
     */
    readonly privateSubnetIds?: string[];
    /**
     * The intra subnet IDs if provided or lookups are enabled.
     */
    readonly intraSubnetIds?: string[];
    /**
     * The redshift subnet IDs if provided or lookups are enabled.
     */
    readonly redshiftSubnetIds?: string[];
    /**
     * The database subnet IDs if provided or lookups are enabled.
     */
    readonly databaseSubnetIds?: string[];
    /**
     * The elasticache subnet IDs if provided or lookups are enabled.
     */
    readonly elasticacheSubnetIds?: string[];
    /**
     * The outpost subnet IDs if provided or lookups are enabled.
     */
    readonly outpostSubnetIds?: string[];
    /**
     * The public ALB ARNs if provided or lookups are enabled.
     */
    readonly publicAlbArns?: string[];
    /**
     * The private ALB ARNs if provided or lookups are enabled.
     */
    readonly privateAlbArns?: string[];
    /**
     * The certificate ARNs on the public ALBs if provided or lookups are enabled.
     */
    readonly publicAlbCertificateArns?: string[];
    /**
     * The certificate ARNs on the private ALbs if provided or lookups are enabled.
     */
    readonly privateAlbCertificateArns?: string[];
    /**
     * The alternative public ALB ARNs if provided or lookups are enabled.
     */
    readonly altPublicAlbArns?: string[];
    /**
     * The alternative private ALB ARNs if provided or lookups are enabled.
     */
    readonly altPrivateAlbArns?: string[];
    /**
     * The certificate ARNs on the alternative public ALBs if provided or lookups are enabled.
     */
    readonly altPublicAlbCertificateArns?: string[];
    /**
     * The certificate ARNs on the alternative private ALbs if provided or lookups are enabled.
     */
    readonly altPrivateAlbCertificateArns?: string[];
    /**
     * The public certificate ARN if provided or lookups are enabled.
     */
    readonly publicCertificateArn?: string;
    /**
     * The private certificate ARN if provided or lookups are enabled.
     */
    readonly privateCertificateArn?: string;
    /**
     * The CloudFront certificate ARN if provided or lookups are enabled.
     */
    readonly cloudFrontCertificateArn?: string;
    /**
     * The public zone name if provided or lookups are enabled.
     */
    readonly publicZoneName?: string;
    /**
     * The private zone name if provided or lookups are enabled.
     */
    readonly privateZoneName?: string;
    /**
     * Creates a new NetworkParameters instance.
     *
     * @param scope the parent scope
     * @param id the id of the instance
     * @param props properties for the instance
     */
    constructor(scope: Construct, id: string, props: NetworkParametersProps);
}
