"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NetworkParameters = void 0;
const aws_ssm_1 = require("aws-cdk-lib/aws-ssm");
const aws_cdk_1 = require("../../aws-cdk");
const truemark_1 = require("../../truemark");
/**
 * Stores and retrieves network infrastructure identifiers using
 * AWS Systems Manager Parameter Store.
 */
class NetworkParameters extends aws_cdk_1.ExtendedConstruct {
    /**
     * Creates a new NetworkParameters instance.
     *
     * @param scope the parent scope
     * @param id the id of the instance
     * @param props properties for the instance
     */
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z;
        super(scope, id, {
            standardTags: aws_cdk_1.StandardTags.merge(props.standardTags, truemark_1.LibStandardTags),
        });
        const create = (_a = props.create) !== null && _a !== void 0 ? _a : true;
        const prefix = (_b = props.prefix) !== null && _b !== void 0 ? _b : '/network';
        const path = `${prefix}/${props.name}`;
        this.vpcParameterPath = `${path}/vpc`;
        this.azsParameterPath = `${path}/azs`;
        this.publicSubnetsParameterPath = `${path}/public_subnets`;
        this.privateSubnetsParameterPath = `${path}/private_subnets`;
        this.intraSubnetsParameterPath = `${path}/intra_subnets`;
        this.redshiftSubnetsParameterPath = `${path}/redshift_subnets`;
        this.databaseSubnetsParameterPath = `${path}/database_subnets`;
        this.elasticacheSubnetsParameterPath = `${path}/elasticache_subnets`;
        this.outpostSubnetsParameterPath = `${path}/outpost_subnets`;
        this.publicAlbsParameterPath = `${path}/public_albs`;
        this.privateAlbsParameterPath = `${path}/private_albs`;
        this.publicAlbCertificatesParameterPath = `${path}/public_alb_certificates`;
        this.privateAlbCertificatesParameterPath = `${path}/private_alb_certificates`;
        this.altPublicAlbsParameterPath = `${path}/alt_public_albs`;
        this.altPrivateAlbsParameterPath = `${path}/alt_private_albs`;
        this.altPublicAlbCertificatesParameterPath = `${path}/alt_public_alb_certificates`;
        this.altPrivateAlbCertificatesParameterPath = `${path}/alt_private_alb_certificates`;
        this.publicCertificateParameterPath = `${path}/public_certificate`;
        this.privateCertificateParameterPath = `${path}/private_certificate`;
        this.cloudFrontCertificateParameterPath = `${path}/cloudfront_certificate`;
        this.publicZoneParameterPath = `${path}/public_zone`;
        this.privateZoneParameterPath = `${path}/private_zone`;
        if (create) {
            if (props.vpcId) {
                this.vpcParameter = new aws_ssm_1.StringParameter(this, 'VpcId', {
                    parameterName: this.vpcParameterPath,
                    stringValue: props.vpcId,
                });
                this.vpcId = props.vpcId;
            }
            if (props.azs) {
                this.azsParameter = new aws_ssm_1.StringListParameter(this, 'AZs', {
                    parameterName: this.azsParameterPath,
                    stringListValue: props.azs,
                });
                this.azs = props.azs;
            }
            if (props.publicSubnetIds) {
                this.publicSubnetsParameter = new aws_ssm_1.StringListParameter(this, 'PublicSubnets', {
                    parameterName: this.publicSubnetsParameterPath,
                    stringListValue: props.publicSubnetIds,
                });
                this.publicSubnetIds = props.privateSubnetIds;
            }
            if (props.privateSubnetIds) {
                this.privateSubnetsParameter = new aws_ssm_1.StringListParameter(this, 'PrivateSubnets', {
                    parameterName: this.privateSubnetsParameterPath,
                    stringListValue: props.privateSubnetIds,
                });
                this.privateSubnetIds = props.privateSubnetIds;
            }
            if (props.intraSubnetIds) {
                this.intraSubnetsParameter = new aws_ssm_1.StringListParameter(this, 'IntraSubnets', {
                    parameterName: this.intraSubnetsParameterPath,
                    stringListValue: props.intraSubnetIds,
                });
                this.intraSubnetIds = props.intraSubnetIds;
            }
            if (props.redshiftSubnetIds) {
                this.redshiftSubnetsParameter = new aws_ssm_1.StringListParameter(this, 'RedshiftSubnets', {
                    parameterName: this.redshiftSubnetsParameterPath,
                    stringListValue: props.redshiftSubnetIds,
                });
                this.redshiftSubnetIds = props.redshiftSubnetIds;
            }
            if (props.databaseSubnetIds) {
                this.databaseSubnetsParameter = new aws_ssm_1.StringListParameter(this, 'DatabaseSubnets', {
                    parameterName: this.databaseSubnetsParameterPath,
                    stringListValue: props.databaseSubnetIds,
                });
                this.databaseSubnetIds = props.databaseSubnetIds;
            }
            if (props.elasticacheSubnetIds) {
                this.elasticacheSubnetsParameter = new aws_ssm_1.StringListParameter(this, 'ElasticacheSubnets', {
                    parameterName: this.elasticacheSubnetsParameterPath,
                    stringListValue: props.elasticacheSubnetIds,
                });
                this.elasticacheSubnetIds = props.elasticacheSubnetIds;
            }
            if (props.outpostSubnetIds) {
                this.outpostSubnetsPrameter = new aws_ssm_1.StringListParameter(this, 'OutpostSubnets', {
                    parameterName: this.outpostSubnetsParameterPath,
                    stringListValue: props.outpostSubnetIds,
                });
                this.outpostSubnetIds = props.outpostSubnetIds;
            }
            if (props.publicAlbArns) {
                this.publicAlbsParameter = new aws_ssm_1.StringListParameter(this, 'PublicAlbs', {
                    parameterName: this.publicAlbsParameterPath,
                    stringListValue: props.publicAlbArns,
                });
                this.publicAlbArns = props.publicAlbArns;
            }
            if (props.privateAlbArns) {
                this.privateAlbsParameter = new aws_ssm_1.StringListParameter(this, 'PrivateAlbs', {
                    parameterName: this.privateAlbsParameterPath,
                    stringListValue: props.privateAlbArns,
                });
                this.privateAlbArns = props.privateAlbArns;
            }
            if (props.publicAlbCertificateArns) {
                this.publicAlbCertificatesParameter = new aws_ssm_1.StringListParameter(this, 'PublicAlbCertificates', {
                    parameterName: this.publicAlbCertificatesParameterPath,
                    stringListValue: props.publicAlbCertificateArns,
                });
            }
            if (props.privateAlbCertificateArns) {
                this.privateAlbCertificatesParameter = new aws_ssm_1.StringListParameter(this, 'PrivateAlbCertificates', {
                    parameterName: this.privateAlbCertificatesParameterPath,
                    stringListValue: props.privateAlbCertificateArns,
                });
            }
            if (props.altPublicAlbArns) {
                this.altPublicAlbsParameter = new aws_ssm_1.StringListParameter(this, 'AltPublicAlbs', {
                    parameterName: this.altPublicAlbsParameterPath,
                    stringListValue: props.altPublicAlbArns,
                });
            }
            if (props.altPrivateAlbArns) {
                this.altPrivateAlbsParameter = new aws_ssm_1.StringListParameter(this, 'AltPrivateAlbs', {
                    parameterName: this.altPrivateAlbsParameterPath,
                    stringListValue: props.altPrivateAlbArns,
                });
            }
            if (props.altPublicAlbCertificateArns) {
                this.altPublicAlbCertificatesParameter = new aws_ssm_1.StringListParameter(this, 'AltPublicAlbCertificates', {
                    parameterName: this.altPublicAlbCertificatesParameterPath,
                    stringListValue: props.altPublicAlbCertificateArns,
                });
            }
            if (props.altPrivateAlbCertificateArns) {
                this.altPrivateAlbCertificatesParameter = new aws_ssm_1.StringListParameter(this, 'AltPrivateAlbCertificates', {
                    parameterName: this.altPrivateAlbCertificatesParameterPath,
                    stringListValue: props.altPrivateAlbCertificateArns,
                });
            }
            if (props.publicCertificateArn) {
                this.publicCertificateParameter = new aws_ssm_1.StringParameter(this, 'PublicCertificate', {
                    parameterName: this.publicCertificateParameterPath,
                    stringValue: props.publicCertificateArn,
                });
            }
            if (props.privateCertificateArn) {
                this.privateCertificateParameter = new aws_ssm_1.StringParameter(this, 'PrivateCertificate', {
                    parameterName: this.privateCertificateParameterPath,
                    stringValue: props.privateCertificateArn,
                });
            }
            if (props.cloudFontCertificateArn) {
                this.cloudFrontCertificateParameter = new aws_ssm_1.StringParameter(this, 'CloudFrontCertificate', {
                    parameterName: this.cloudFrontCertificateParameterPath,
                    stringValue: props.cloudFontCertificateArn,
                });
            }
            if (props.publicZoneName) {
                this.publicZoneParameter = new aws_ssm_1.StringParameter(this, 'PublicZone', {
                    parameterName: this.publicZoneParameterPath,
                    stringValue: props.publicZoneName,
                });
            }
            if (props.privateZoneName) {
                this.privateZoneParameter = new aws_ssm_1.StringParameter(this, 'PrivateZone', {
                    parameterName: this.privateZoneParameterPath,
                    stringValue: props.privateZoneName,
                });
            }
        }
        if ((_c = props.lookupVpc) !== null && _c !== void 0 ? _c : true) {
            if (!this.vpcId) {
                this.vpcId = aws_ssm_1.StringParameter.valueFromLookup(this, this.vpcParameterPath);
            }
        }
        if ((_d = props.lookupAzs) !== null && _d !== void 0 ? _d : true) {
            if (!this.azs) {
                this.azs = aws_ssm_1.StringParameter.valueFromLookup(this, this.azsParameterPath).split(',');
            }
        }
        if ((_e = props.lookupPublicSubnets) !== null && _e !== void 0 ? _e : true) {
            if (!this.publicSubnetIds) {
                this.publicSubnetIds = aws_ssm_1.StringParameter.valueFromLookup(this, this.publicSubnetsParameterPath).split(',');
            }
        }
        if ((_f = props.lookupPrivateSubnets) !== null && _f !== void 0 ? _f : true) {
            if (!this.privateSubnetIds) {
                this.privateSubnetIds = aws_ssm_1.StringParameter.valueFromLookup(this, this.privateSubnetsParameterPath).split(',');
            }
        }
        if ((_g = props.lookupIntraSubnets) !== null && _g !== void 0 ? _g : false) {
            if (!this.intraSubnetIds) {
                this.intraSubnetIds = aws_ssm_1.StringParameter.valueFromLookup(this, this.intraSubnetsParameterPath).split(',');
            }
        }
        if ((_h = props.lookupRedshiftSubnets) !== null && _h !== void 0 ? _h : false) {
            if (!this.redshiftSubnetIds) {
                this.redshiftSubnetIds = aws_ssm_1.StringParameter.valueFromLookup(this, this.redshiftSubnetsParameterPath).split(',');
            }
        }
        if ((_j = props.lookupDatabaseSubnets) !== null && _j !== void 0 ? _j : false) {
            if (!this.databaseSubnetIds) {
                this.databaseSubnetIds = aws_ssm_1.StringParameter.valueFromLookup(this, this.databaseSubnetsParameterPath).split(',');
            }
        }
        if ((_k = props.lookupElasticacheSubnets) !== null && _k !== void 0 ? _k : false) {
            if (!this.elasticacheSubnetIds) {
                this.elasticacheSubnetIds = aws_ssm_1.StringParameter.valueFromLookup(this, this.elasticacheSubnetsParameterPath).split(',');
            }
        }
        if ((_l = props.lookupOutpostSubnets) !== null && _l !== void 0 ? _l : false) {
            if (!this.outpostSubnetIds) {
                this.outpostSubnetIds = aws_ssm_1.StringParameter.valueFromLookup(this, this.outpostSubnetsParameterPath).split(',');
            }
        }
        if ((_m = props.lookupPublicAlbs) !== null && _m !== void 0 ? _m : false) {
            if (!this.publicAlbArns) {
                this.publicAlbArns = aws_ssm_1.StringParameter.valueFromLookup(this, this.publicAlbsParameterPath).split(',');
            }
        }
        if ((_o = props.lookupPrivateAlbs) !== null && _o !== void 0 ? _o : false) {
            if (!this.privateAlbArns) {
                this.privateAlbArns = aws_ssm_1.StringParameter.valueFromLookup(this, this.privateAlbsParameterPath).split(',');
            }
        }
        if ((_p = props.lookupPublicAlbCertificates) !== null && _p !== void 0 ? _p : false) {
            if (!this.publicAlbCertificateArns) {
                this.publicAlbCertificateArns = aws_ssm_1.StringParameter.valueFromLookup(this, this.publicAlbCertificatesParameterPath).split(',');
            }
        }
        if ((_q = props.lookupPrivateAlbCertificates) !== null && _q !== void 0 ? _q : false) {
            if (!this.privateAlbCertificateArns) {
                this.privateAlbCertificateArns = aws_ssm_1.StringParameter.valueFromLookup(this, this.privateAlbCertificatesParameterPath).split(',');
            }
        }
        if ((_r = props.lookupAltPublicAlbs) !== null && _r !== void 0 ? _r : false) {
            if (!this.altPublicAlbArns) {
                this.altPublicAlbArns = aws_ssm_1.StringParameter.valueFromLookup(this, this.altPublicAlbsParameterPath).split(',');
            }
        }
        if ((_s = props.lookupAltPrivateAlbs) !== null && _s !== void 0 ? _s : false) {
            if (!this.altPrivateAlbArns) {
                this.altPrivateAlbArns = aws_ssm_1.StringParameter.valueFromLookup(this, this.altPrivateAlbsParameterPath).split(',');
            }
        }
        if ((_t = props.lookupAltPublicAlbCertificates) !== null && _t !== void 0 ? _t : false) {
            if (!this.altPublicAlbCertificateArns) {
                this.altPublicAlbCertificateArns = aws_ssm_1.StringParameter.valueFromLookup(this, this.altPublicAlbCertificatesParameterPath).split(',');
            }
        }
        if ((_u = props.lookupAltPrivateAlbCertificates) !== null && _u !== void 0 ? _u : false) {
            if (!this.altPrivateAlbCertificateArns) {
                this.altPrivateAlbCertificateArns = aws_ssm_1.StringParameter.valueFromLookup(this, this.altPrivateAlbCertificatesParameterPath).split(',');
            }
        }
        if ((_v = props.lookupPublicCertificate) !== null && _v !== void 0 ? _v : false) {
            if (!this.publicCertificateArn) {
                this.publicCertificateArn = aws_ssm_1.StringParameter.valueFromLookup(this, this.publicCertificateParameterPath);
            }
        }
        if ((_w = props.lookupPrivateCertificate) !== null && _w !== void 0 ? _w : false) {
            if (!this.privateCertificateArn) {
                this.privateCertificateArn = aws_ssm_1.StringParameter.valueFromLookup(this, this.privateCertificateParameterPath);
            }
        }
        if ((_x = props.lookupCloudFrontCertificate) !== null && _x !== void 0 ? _x : false) {
            if (!this.cloudFrontCertificateArn) {
                this.cloudFrontCertificateArn = aws_ssm_1.StringParameter.valueFromLookup(this, this.cloudFrontCertificateParameterPath);
            }
        }
        if ((_y = props.lookupPublicZone) !== null && _y !== void 0 ? _y : false) {
            if (!this.publicZoneName) {
                this.publicZoneName = aws_ssm_1.StringParameter.valueFromLookup(this, this.publicZoneParameterPath);
            }
        }
        if ((_z = props.lookupPrivateZone) !== null && _z !== void 0 ? _z : false) {
            if (!this.privateZoneName) {
                this.privateZoneName = aws_ssm_1.StringParameter.valueFromLookup(this, this.privateZoneParameterPath);
            }
        }
    }
}
exports.NetworkParameters = NetworkParameters;
//# sourceMappingURL=network-parameters.js.map