"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShellHelper = void 0;
const child_process_1 = require("child_process");
const process = require("process");
const fs = require("fs");
/**
 * Simple helper class for executing shell scripts and commands
 */
class ShellHelper {
    static version(command, args) {
        const res = (0, child_process_1.spawnSync)(command, args);
        if (res.status !== 0) {
            return null;
        }
        const match = String(res.stdout).match(/[\d\\.]+/);
        return match ? match.toString() : null;
    }
    static bashVersion() {
        return ShellHelper.version('bash', ['--version']);
    }
    static pythonVersion() {
        return ShellHelper.version('python', ['-V']);
    }
    static nodeVersion() {
        return ShellHelper.version('node', ['--version']);
    }
    static goVersion() {
        return ShellHelper.version('go', ['version']);
    }
    static dotnetVersion() {
        return ShellHelper.version('dotnet', ['--version']);
    }
    static checkDirectoryAccess(dir) {
        if (dir !== undefined) {
            fs.accessSync(dir);
            if (!fs.lstatSync(dir).isDirectory()) {
                throw new Error(`${dir} is not a directory`);
            }
        }
    }
    static executeBash(props) {
        ShellHelper.checkDirectoryAccess(props.workingDirectory);
        const res = (0, child_process_1.spawnSync)('bash', {
            input: props.script,
            cwd: props.workingDirectory,
            stdio: ['pipe', process.stdout, process.stderr],
            env: {
                ...process.env,
                ...props.environment,
            },
        });
        if (res.error) {
            throw res.error;
        }
        return res.status === 0;
    }
    static executeBashScript(props) {
        ShellHelper.checkDirectoryAccess(props.workingDirectory);
        const res = (0, child_process_1.spawnSync)('bash', [props.script], {
            cwd: props.workingDirectory,
            stdio: 'inherit',
            env: {
                ...process.env,
                ...props.environment,
            },
        });
        if (res.error) {
            throw res.error;
        }
        return res.status === 0;
    }
}
exports.ShellHelper = ShellHelper;
//# sourceMappingURL=shell-helper.js.map