"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StringHelper = void 0;
/**
 * Helper methods for use on Strings.
 */
class StringHelper {
    /**
     * Tests if a string is lower case alphanumeric
     *
     * @param str the string to check
     */
    static isLowerAlphanumeric(str) {
        if (str) {
            return /^[a-z0-9]+$/.test(str);
        }
        return false;
    }
    /**
     * Tests if a string is upper case alphanumeric.
     *
     * @param str the string to check
     */
    static isUpperAlphanumeric(str) {
        if (str) {
            return /^[A-Z0-9]+$/.test(str);
        }
        return false;
    }
    /**
     * Tests if a string is PascalCase.
     *
     * @param str the string to test
     */
    static isPascalCase(str) {
        if (str) {
            return /^[A-Z](([a-z0-9]+[A-Z]?)*)$/.test(str);
        }
        return false;
    }
    /**
     * Tests if a string is camelCase.
     *
     * @param str the string to test
     */
    static isCamelCase(str) {
        if (str) {
            return /^[a-z][a-z0-9]*(([A-Z][a-z0-9]+)*[A-Z]?|([a-z0-9]+[A-Z])*|[A-Z])$/.test(str);
        }
        return false;
    }
    /**
     * Converts a string to snake_case
     *
     * @param str the string to convert
     */
    static toSnakeCase(str) {
        return (str.match(/[A-Z]{2,}(?=[A-Z][a-z]+[0-9]*|\b)|[A-Z]?[a-z]+[0-9]*|[A-Z]|[0-9]+/g) || [])
            .map(x => x.toLowerCase())
            .join('_');
    }
    /**
     * Converts a string to kebab-case
     *
     * @param str the string to convert
     */
    static toKebabCase(str) {
        return (str.match(/[A-Z]{2,}(?=[A-Z][a-z]+[0-9]*|\b)|[A-Z]?[a-z]+[0-9]*|[A-Z]|[0-9]+/g) || [])
            .map(x => x.toLowerCase())
            .join('-');
    }
    /**
     * Converts a string to camelCase.
     *
     * @param str the string to convert
     */
    static toCamelCase(str) {
        str = this.toPascalCase(str);
        return str.charAt(0).toLowerCase() + str.slice(1);
    }
    /**
     * Converts a string to PascalCase.
     *
     * @param str the string to convert
     */
    static toPascalCase(str) {
        return (str.match(/[a-zA-Z0-9]+/g) || [])
            .map(x => `${x.charAt(0).toUpperCase()}${x.slice(1)}`)
            .join('');
    }
}
exports.StringHelper = StringHelper;
//# sourceMappingURL=string-helper.js.map